@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -29,17 +29,23 @@ import sys
 
 # pylint: disable=I0021,invalid-name,redefined-builtin
 
+if str is bytes:
+    import __builtin__ as builtins  # @UnresolvedImport @UnusedImport pylint: disable=I0021,import-error
+else:
+    import builtins  # @UnresolvedImport @Reimport pylint: disable=I0021,import-error
+
 # Work around for CPython 3.x renaming "long" to "int".
 if str is bytes:
     long = long  # @ReservedAssignment pylint: disable=I0021,undefined-variable
 else:
-    long = int   # @ReservedAssignment
+    long = int  # @ReservedAssignment
 
 # Work around for CPython 3.x renaming "unicode" to "str".
 if str is bytes:
     unicode = unicode  # @ReservedAssignment pylint: disable=I0021,undefined-variable
 else:
-    unicode = str      # @ReservedAssignment
+    unicode = str  # @ReservedAssignment
+
 
 def iterItems(d):
     try:
@@ -47,27 +53,34 @@ def iterItems(d):
     except AttributeError:
         return d.items()
 
+
 if str is not bytes:
-    raw_input = input      # @ReservedAssignment
+    raw_input = input  # @ReservedAssignment
 else:
     raw_input = raw_input  # @ReservedAssignment
 
 if str is bytes:
-    xrange = xrange # @ReservedAssignment pylint: disable=I0021,undefined-variable
+    xrange = xrange  # @ReservedAssignment pylint: disable=I0021,undefined-variable
 else:
     xrange = range  # @ReservedAssignment
 
 
 if str is bytes:
-    from urllib import urlretrieve # @UnresolvedImport pylint: disable=I0021,import-error,no-name-in-module
+    from urllib import (  # pylint: disable=I0021,import-error,no-name-in-module
+        urlretrieve,  # @UnresolvedImport @UnusedImport
+    )
 else:
-    from urllib.request import urlretrieve # @UnresolvedImport pylint: disable=I0021,import-error,no-name-in-module
-
+    from urllib.request import (  # pylint: disable=I0021,import-error,no-name-in-module
+        urlretrieve,  #  @Reimport @UnresolvedImport
+    )
 if str is bytes:
-    from cStringIO import StringIO # @UnresolvedImport pylint: disable=I0021,import-error
+    from cStringIO import (  # pylint: disable=I0021,import-error
+        StringIO,  # @UnresolvedImport @UnusedImport
+    )
 else:
-    from io import StringIO # @UnresolvedImport pylint: disable=I0021,import-error
-
+    from io import (
+        StringIO,  # @UnresolvedImport @Reimport pylint: disable=I0021,import-error
+    )
 try:
     from functools import total_ordering
 except ImportError:
@@ -81,8 +94,9 @@ except ImportError:
 
         return cls
 
+
 if str is bytes:
-    intern = intern      # @ReservedAssignment pylint: disable=I0021,undefined-variable
+    intern = intern  # @ReservedAssignment pylint: disable=I0021,undefined-variable
 else:
     intern = sys.intern  # @ReservedAssignment @UndefinedVariable
 
@@ -94,3 +108,4 @@ assert StringIO
 assert type(xrange) is type, xrange
 assert total_ordering
 assert intern
+assert builtins
