@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -33,7 +33,7 @@ from types import BuiltinFunctionType
 from nuitka.__past__ import (  # pylint: disable=I0021,redefined-builtin
     long,
     unicode,
-    xrange
+    xrange,
 )
 from nuitka.Builtins import builtin_anon_values, builtin_named_values_list
 
@@ -41,6 +41,7 @@ from nuitka.Builtins import builtin_anon_values, builtin_named_values_list
 class ExceptionCannotNamify(Exception):
     pass
 
+
 def namifyConstant(constant):
     # Many branches, statements and every case has a return, this is a huge case
     # statement, that encodes the naming policy of constants, with often complex
@@ -94,15 +95,15 @@ def namifyConstant(constant):
                 "minus" if math.copysign(1, constant) < 0 else "plus"
             )
 
-        return "float_%s" % repr(constant).replace('.', '_').\
-          replace('-', "_minus_").replace('+', "")
+        return "float_%s" % repr(constant).replace(".", "_").replace(
+            "-", "_minus_"
+        ).replace("+", "")
     elif type(constant) is complex:
         value = "%s__%s" % (constant.real, constant.imag)
 
-        value = value.replace('+', 'p').replace('-', 'm').\
-          replace('.', '_')
+        value = value.replace("+", "p").replace("-", "m").replace(".", "_")
 
-        if value.startswith('(') and value.endswith(')'):
+        if value.startswith("(") and value.endswith(")"):
             value = value[1:-1]
 
         return "complex_%s" % value
@@ -126,11 +127,7 @@ def namifyConstant(constant):
             return "tuple_empty"
         else:
             try:
-                result = '_'.join(
-                    namifyConstant(value)
-                    for value in
-                    constant
-                )
+                result = "_".join(namifyConstant(value) for value in constant)
 
                 if len(result) > 60:
                     result = _digest(repr(constant))
@@ -145,11 +142,7 @@ def namifyConstant(constant):
             return "list_empty"
         else:
             try:
-                result = '_'.join(
-                    namifyConstant(value)
-                    for value in
-                    constant
-                )
+                result = "_".join(namifyConstant(value) for value in constant)
 
                 if len(result) > 60:
                     result = _digest(repr(constant))
@@ -163,13 +156,16 @@ def namifyConstant(constant):
         return "bytearray_" + _digest(repr(constant))
     elif type(constant) is xrange:
         return "xrange_%s" % (
-            str(constant)[7 if str is bytes else 6:-1].replace(' ', "").replace(',', '_').replace('-', "neg")
+            str(constant)[7 if str is bytes else 6 : -1]
+            .replace(" ", "")
+            .replace(",", "_")
+            .replace("-", "neg")
         )
     elif type(constant) is slice:
         return "slice_%s_%s_%s" % (
             namifyConstant(constant.start),
             namifyConstant(constant.stop),
-            namifyConstant(constant.step)
+            namifyConstant(constant.step),
         )
     elif constant in builtin_anon_values:
         return "anon_%s" % builtin_anon_values[constant]
@@ -184,35 +180,44 @@ def namifyConstant(constant):
     else:
         raise ExceptionCannotNamify("%r" % constant, type(constant))
 
+
 _re_str_needs_no_digest = re.compile(r"^([a-z]|[A-Z]|[0-9]|_){1,40}$", re.S)
 
+
 def _namifyString(string):
     # Many branches case has a return, encodes the naming policy of strings
     # constants, with often complex decisions to make, pylint: disable=too-many-return-statements
 
     if string in ("", b""):
         return "empty"
-    elif string == ' ':
+    elif string == " ":
         return "space"
-    elif string == '.':
+    elif string == ".":
         return "dot"
-    elif string == '\n':
+    elif string == "\n":
         return "newline"
-    elif type(string) is str and \
-         _re_str_needs_no_digest.match(string) and \
-         '\n' not in string:
+    elif (
+        type(string) is str
+        and _re_str_needs_no_digest.match(string)
+        and "\n" not in string
+    ):
         # Some strings can be left intact for source code readability.
         return "plain_" + string
     elif len(string) == 1:
         return "chr_%d" % ord(string)
-    elif len(string) > 2 and string[0] == '<' and string[-1] == '>' and \
-         _re_str_needs_no_digest.match(string[1:-1]) and \
-         '\n' not in string:
+    elif (
+        len(string) > 2
+        and string[0] == "<"
+        and string[-1] == ">"
+        and _re_str_needs_no_digest.match(string[1:-1])
+        and "\n" not in string
+    ):
         return "angle_" + string[1:-1]
     else:
         # Others are better digested to not cause compiler trouble
         return "digest_" + _digest(repr(string))
 
+
 def _isAscii(string):
     try:
         _unused = str(string)
@@ -221,6 +226,7 @@ def _isAscii(string):
     except UnicodeEncodeError:
         return False
 
+
 def _digest(value):
     if str is bytes:
         # Python2 is simple
