@@ -1,4 +1,4 @@
-#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -20,33 +20,17 @@
 """
 
 template_constants_reading = """
-#include "nuitka/prelude.hpp"
+#include "nuitka/prelude.h"
+#include "structseq.h"
 
 // Sentinel PyObject to be used for all our call iterator endings. It will
 // become a PyCObject pointing to NULL. It's address is unique, and that's
 // enough for us to use it as sentinel value.
 PyObject *_sentinel_value = NULL;
 
-%(constant_declarations)s
+PyObject *Nuitka_dunder_compiled_value = NULL;
 
-#if defined(_WIN32) && defined(_NUITKA_EXE)
-#include <Windows.h>
-const unsigned char* constant_bin;
-struct __initResourceConstants
-{
-    __initResourceConstants()
-    {
-        constant_bin = (const unsigned char*)LockResource(
-            LoadResource(
-                NULL,
-                FindResource(NULL, MAKEINTRESOURCE(3), RT_RCDATA)
-            )
-        );
-    }
-} __initResourceConstants_static_initializer;
-#else
-extern "C" const unsigned char constant_bin[];
-#endif
+%(constant_declarations)s
 
 static void _createGlobalConstants( void )
 {
@@ -67,7 +51,52 @@ static void _createGlobalConstants( void )
         (char *)"executable",
         %(sys_executable)s
     );
+
+    /* Set the "sys.executable" path to the original CPython executable. */
+    PySys_SetObject(
+        (char *)"prefix",
+        %(sys_prefix)s
+    );
+
 #endif
+
+    static PyTypeObject Nuitka_VersionInfoType;
+
+    // Same fields as "sys.version_info" except no serial number.
+    static PyStructSequence_Field Nuitka_VersionInfoFields[] = {
+        {(char *)"major", (char *)"Major release number"},
+        {(char *)"minor", (char *)"Minor release number"},
+        {(char *)"micro", (char *)"Micro release number"},
+        {(char *)"releaselevel", (char *)"'alpha', 'beta', 'candidate', or 'release'"},
+        {0}
+    };
+
+    static PyStructSequence_Desc Nuitka_VersionInfoDesc = {
+        (char *)"__nuitka_version__",                                    /* name */
+        (char *)"__compiled__\\n\\nVersion information as a named tuple.", /* doc */
+        Nuitka_VersionInfoFields,                                        /* fields */
+        4
+    };
+
+    PyStructSequence_InitType(&Nuitka_VersionInfoType, &Nuitka_VersionInfoDesc);
+
+    Nuitka_dunder_compiled_value = PyStructSequence_New(&Nuitka_VersionInfoType);
+    assert(Nuitka_dunder_compiled_value != NULL);
+
+    PyStructSequence_SET_ITEM(Nuitka_dunder_compiled_value, 0, PyInt_FromLong(%(nuitka_version_major)s));
+    PyStructSequence_SET_ITEM(Nuitka_dunder_compiled_value, 1, PyInt_FromLong(%(nuitka_version_minor)s));
+    PyStructSequence_SET_ITEM(Nuitka_dunder_compiled_value, 2, PyInt_FromLong(%(nuitka_version_micro)s));
+
+#if PYTHON_VERSION < 300
+    PyStructSequence_SET_ITEM(Nuitka_dunder_compiled_value, 3, PyString_FromString("%(nuitka_version_level)s"));
+#else
+    PyStructSequence_SET_ITEM(Nuitka_dunder_compiled_value, 3, PyUnicode_FromString("%(nuitka_version_level)s"));
+#endif
+    // Prevent users from creating the Nuitka version type object.
+    Nuitka_VersionInfoType.tp_init = NULL;
+    Nuitka_VersionInfoType.tp_new = NULL;
+
+
 }
 
 // In debug mode we can check that the constants were not tampered with in any
@@ -80,7 +109,6 @@ void checkGlobalConstants( void )
 }
 #endif
 
-
 void createGlobalConstants( void )
 {
     if ( _sentinel_value == NULL )
@@ -98,5 +126,6 @@ void createGlobalConstants( void )
 }
 """
 
-from . import TemplateDebugWrapper # isort:skip
+from . import TemplateDebugWrapper  # isort:skip
+
 TemplateDebugWrapper.checkDebug(globals())
