@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -19,6 +19,7 @@
 
 """
 
+import collections
 import distutils.command.build  # @UnresolvedImport pylint: disable=I0021,import-error,no-name-in-module
 import distutils.command.install  # @UnresolvedImport pylint: disable=I0021,import-error,no-name-in-module
 import os
@@ -28,6 +29,8 @@ import sys
 
 import wheel.bdist_wheel  # @UnresolvedImport pylint: disable=I0021,import-error,no-name-in-module
 
+from nuitka.__past__ import unicode  # pylint: disable=I0021,redefined-builtin
+
 
 def setuptools_build_hook(dist, keyword, value):
     # If the user project setup.py includes the key "build_with_nuitka=True" all
@@ -58,22 +61,24 @@ class build(distutils.command.build.build):
         self._buildPackage(os.path.abspath(self.build_lib))
 
     def _buildPackage(self, build_lib):
+        # High complexity, pylint: disable=too-many-branches,too-many-locals
+
         # Nuitka wants the main package by filename, probably we should stop
-        # needing that, pylint: disable=too-many-locals
+        # needing that.
         from nuitka.importing.Importing import findModule, setMainScriptDirectory
 
         old_dir = os.getcwd()
         os.chdir(build_lib)
 
         # Search in the build directory preferably.
-        setMainScriptDirectory('.')
+        setMainScriptDirectory(".")
 
         package, main_filename, finding = findModule(
-            importing      = None,
-            module_name    = self.main_package,
-            parent_package = None,
-            level          = 0,
-            warn           = False
+            importing=None,
+            module_name=self.main_package,
+            parent_package=None,
+            level=0,
+            warn=False,
         )
 
         # Check expectations, e.g. do not compile built-in modules.
@@ -104,21 +109,35 @@ class build(distutils.command.build.build):
 
         command = [
             sys.executable,
-            "-m", "nuitka",
+            "-m",
+            "nuitka",
             "--module",
             "--plugin-enable=pylint-warnings",
             "--output-dir=%s" % output_dir,
-            "--recurse-dir=%s" % self.main_package,
-            "--recurse-to=%s" % self.main_package,
-            "--recurse-not-to=*.tests",
+            "--include-package=%s" % self.main_package,
+            "--nofollow-import-to=*.tests",
             "--show-modules",
             "--remove-output",
-            main_filename,
         ]
 
-        subprocess.check_call(
-            command
-        )
+        # Process any extra options from setuptools
+        if "nuitka" in self.distribution.command_options:
+            for option, details in self.distribution.command_options["nuitka"].items():
+                option = "--" + option.lstrip("-")
+                _source, value = details
+                if value is None:
+                    command.append(option)
+                elif isinstance(value, collections.Iterable) and not isinstance(
+                    value, (unicode, bytes, str)
+                ):
+                    for val in value:
+                        command.append("%s=%s" % (option, val))
+                else:
+                    command.append("%s=%s" % (option, value))
+
+        command.append(main_filename)
+
+        subprocess.check_call(command, cwd=build_lib)
         os.chdir(old_dir)
 
         self.build_lib = build_lib
@@ -144,7 +163,6 @@ class install(distutils.command.install.install):
 
 # pylint: disable=C0103
 class bdist_nuitka(wheel.bdist_wheel.bdist_wheel):
-
     def initialize_options(self):
         # Register the command class overrides above
         dist = self.distribution
@@ -161,13 +179,12 @@ class bdist_nuitka(wheel.bdist_wheel.bdist_wheel):
         self.root_is_pure = False
         self.plat_name_supplied = self.plat_name is not None
 
-    def write_wheelfile(self, wheelfile_base, generator = None):
+    def write_wheelfile(self, wheelfile_base, generator=None):
         if generator is None:
             from nuitka.Version import getNuitkaVersion
+
             generator = "Nuitka (%s)" % getNuitkaVersion()
 
         wheel.bdist_wheel.bdist_wheel.write_wheelfile(
-            self,
-            wheelfile_base = wheelfile_base,
-            generator      = generator
+            self, wheelfile_base=wheelfile_base, generator=generator
         )
