@@ -1,4 +1,4 @@
-#     Copyright 2017, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -22,10 +22,11 @@ point to package directories, which need no "__init__.py" to count as a
 package. Nuitka will pretend for those that there be one, but without content.
 """
 
+import os
 import sys
 from logging import warning
 
-from nuitka.utils import Utils
+from nuitka.utils.FileOperations import listDir
 
 
 def getLoadedPackages():
@@ -49,7 +50,7 @@ def getLoadedPackages():
 def detectPreLoadedPackagePaths():
     result = {}
 
-    for package_name, module  in getLoadedPackages():
+    for package_name, module in getLoadedPackages():
         result[package_name] = list(module.__path__)
 
     return result
@@ -57,8 +58,9 @@ def detectPreLoadedPackagePaths():
 
 preloaded_packages = None
 
+
 def getPreloadedPackagePaths():
-    # We need to set this from the outside, pylint: disable=W0603
+    # We need to set this from the outside, pylint: disable=global-statement
     global preloaded_packages
 
     if preloaded_packages is None:
@@ -68,7 +70,7 @@ def getPreloadedPackagePaths():
 
 
 def setPreloadedPackagePaths(value):
-    # We need to set this from the outside, pylint: disable=W0603
+    # We need to set this from the outside, pylint: disable=global-statement
     global preloaded_packages
 
     preloaded_packages = value
@@ -79,11 +81,11 @@ def getPreloadedPackagePath(package_name):
 
 
 def isPreloadedPackagePath(path):
-    path = Utils.normcase(path)
+    path = os.path.normcase(path)
 
     for paths in getPreloadedPackagePaths().values():
         for element in paths:
-            if Utils.normcase(element) == path:
+            if os.path.normcase(element) == path:
                 return True
 
     return False
@@ -96,29 +98,30 @@ def detectPthImportedPackages():
     pth_imports = set()
 
     for prefix in sys.modules["site"].getsitepackages():
-        if not Utils.isDir(prefix):
+        if not os.path.isdir(prefix):
             continue
 
-        for path, filename in Utils.listDir(prefix):
+        for path, filename in listDir(prefix):
             if filename.endswith(".pth"):
                 try:
                     for line in open(path, "rU"):
                         if line.startswith("import "):
-                            if ';' in line:
-                                line = line[:line.find(';')]
+                            if ";" in line:
+                                line = line[: line.find(";")]
 
-                            for part in line[7:].split(','):
+                            for part in line[7:].split(","):
                                 pth_imports.add(part.strip())
                 except OSError:
                     warning("Python installation problem, cannot read file '%s'.")
 
-
     return tuple(sorted(pth_imports))
 
+
 pth_imported_packages = ()
 
+
 def setPthImportedPackages(value):
-    # We need to set this from the outside, pylint: disable=W0603
+    # We need to set this from the outside, pylint: disable=global-statement
     global pth_imported_packages
 
     pth_imported_packages = value
