@@ -1,4 +1,4 @@
-#     Copyright 2017, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -15,7 +15,7 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-""" Builtin ord/chr nodes
+""" Built-in ord/chr nodes
 
 These are good for optimizations, as they give a very well known result. In the case of
 'chr', it's one of 256 strings, and in case of 'ord' it's one of 256 numbers, so these can
@@ -23,7 +23,7 @@ answer quite a few questions at compile time.
 
 """
 
-from nuitka.optimizations import BuiltinOptimization
+from nuitka.specs import BuiltinParameterSpecs
 
 from .ExpressionBases import ExpressionBuiltinSingleArgBase
 
@@ -31,7 +31,7 @@ from .ExpressionBases import ExpressionBuiltinSingleArgBase
 class ExpressionBuiltinOrd(ExpressionBuiltinSingleArgBase):
     kind = "EXPRESSION_BUILTIN_ORD"
 
-    builtin_spec = BuiltinOptimization.builtin_ord_spec
+    builtin_spec = BuiltinParameterSpecs.builtin_ord_spec
 
     def isKnownToBeIterable(self, count):
         return False
@@ -40,7 +40,7 @@ class ExpressionBuiltinOrd(ExpressionBuiltinSingleArgBase):
 class ExpressionBuiltinChr(ExpressionBuiltinSingleArgBase):
     kind = "EXPRESSION_BUILTIN_CHR"
 
-    builtin_spec = BuiltinOptimization.builtin_chr_spec
+    builtin_spec = BuiltinParameterSpecs.builtin_chr_spec
 
     def isKnownToBeIterable(self, count):
         if self.mayRaiseException(BaseException):
