@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -31,7 +31,7 @@ from .NodeBases import StatementChildrenHavingBase
 from .NodeMakingHelpers import (
     makeStatementExpressionOnlyReplacementNode,
     wrapExpressionWithNodeSideEffects,
-    wrapStatementWithSideEffects
+    wrapStatementWithSideEffects,
 )
 from .OperatorNodes import ExpressionOperationNOT
 from .StatementNodes import StatementsSequence
@@ -40,56 +40,45 @@ from .StatementNodes import StatementsSequence
 class ExpressionConditional(ExpressionChildrenHavingBase):
     kind = "EXPRESSION_CONDITIONAL"
 
-    named_children = (
-        "condition",
-        "expression_yes",
-        "expression_no"
-    )
+    named_children = ("condition", "expression_yes", "expression_no")
 
     def __init__(self, condition, expression_yes, expression_no, source_ref):
         ExpressionChildrenHavingBase.__init__(
             self,
-            values     = {
-                "condition"      : condition,
-                "expression_yes" : expression_yes,
-                "expression_no"  : expression_no
+            values={
+                "condition": condition,
+                "expression_yes": expression_yes,
+                "expression_no": expression_no,
             },
-            source_ref = source_ref
+            source_ref=source_ref,
         )
 
     def getBranches(self):
-        return (
-            self.getExpressionYes(),
-            self.getExpressionNo()
-        )
+        return (self.getExpressionYes(), self.getExpressionNo())
 
-    getExpressionYes = ExpressionChildrenHavingBase.childGetter(
-        "expression_yes"
-    )
-    getExpressionNo = ExpressionChildrenHavingBase.childGetter(
-        "expression_no"
-    )
+    getExpressionYes = ExpressionChildrenHavingBase.childGetter("expression_yes")
+    getExpressionNo = ExpressionChildrenHavingBase.childGetter("expression_no")
 
-    getCondition = ExpressionChildrenHavingBase.childGetter(
-        "condition"
-    )
+    getCondition = ExpressionChildrenHavingBase.childGetter("condition")
 
     def computeExpressionRaw(self, trace_collection):
         # This is rather complex stuff, pylint: disable=too-many-branches
 
         # Query the truth value after the expression is evaluated, once it is
         # evaluated in onExpression, it is known.
-        trace_collection.onExpression(
-            expression = self.getCondition()
-        )
+        trace_collection.onExpression(expression=self.getCondition())
         condition = self.getCondition()
 
         # No need to look any further, if the condition raises, the branches do
         # not matter at all.
         if condition.willRaiseException(BaseException):
-            return condition, "new_raise", """\
+            return (
+                condition,
+                "new_raise",
+                """\
 Conditional expression already raises implicitly in condition, removing \
-branches."""
+branches.""",
+            )
 
         # Tell it we are evaluation it for boolean value only, it may demote
         # itself possibly.
@@ -107,13 +96,10 @@ branches."""
         # relevant.
         if truth_value is not False:
             branch_yes_collection = TraceCollectionBranch(
-                parent = trace_collection,
-                name   = "conditional expression yes branch"
+                parent=trace_collection, name="conditional expression yes branch"
             )
 
-            branch_yes_collection.computeBranch(
-                branch = yes_branch
-            )
+            branch_yes_collection.computeBranch(branch=yes_branch)
 
             # May have just gone away, so fetch it again.
             yes_branch = self.getExpressionYes()
@@ -129,13 +115,10 @@ branches."""
         # Continue to execute for yes branch.
         if truth_value is not True:
             branch_no_collection = TraceCollectionBranch(
-                parent = trace_collection,
-                name   = "conditional expression no branch"
+                parent=trace_collection, name="conditional expression no branch"
             )
 
-            branch_no_collection.computeBranch(
-                branch = no_branch
-            )
+            branch_no_collection.computeBranch(branch=no_branch)
 
             # May have just gone away, so fetch it again.
             no_branch = self.getExpressionNo()
@@ -152,52 +135,47 @@ branches."""
             trace_collection.replaceBranch(branch_no_collection)
         else:
             # Merge into parent execution.
-            trace_collection.mergeBranches(
-                branch_yes_collection,
-                branch_no_collection
-            )
+            trace_collection.mergeBranches(branch_yes_collection, branch_no_collection)
 
         if truth_value is True:
             return (
                 wrapExpressionWithNodeSideEffects(
-                    new_node = self.getExpressionYes(),
-                    old_node = condition
+                    new_node=self.getExpressionYes(), old_node=condition
                 ),
                 "new_expression",
-                "Conditional expression predicted to yes case."
+                "Conditional expression predicted to yes case.",
             )
         elif truth_value is False:
             return (
                 wrapExpressionWithNodeSideEffects(
-                    new_node = self.getExpressionNo(),
-                    old_node = condition
+                    new_node=self.getExpressionNo(), old_node=condition
                 ),
                 "new_expression",
-                "Conditional expression predicted to no case."
+                "Conditional expression predicted to no case.",
             )
         else:
             return self, None, None
 
     def computeExpressionDrop(self, statement, trace_collection):
         result = makeStatementConditional(
-            condition  = self.getCondition(),
-            yes_branch = makeStatementExpressionOnlyReplacementNode(
-                expression = self.getExpressionYes(),
-                node       = self.getExpressionYes()
+            condition=self.getCondition(),
+            yes_branch=makeStatementExpressionOnlyReplacementNode(
+                expression=self.getExpressionYes(), node=self.getExpressionYes()
             ),
-            no_branch  = makeStatementExpressionOnlyReplacementNode(
-                expression = self.getExpressionNo(),
-                node       = self.getExpressionNo()
+            no_branch=makeStatementExpressionOnlyReplacementNode(
+                expression=self.getExpressionNo(), node=self.getExpressionNo()
             ),
-            source_ref = self.source_ref
+            source_ref=self.source_ref,
         )
 
-
         del self.parent
 
-        return result, "new_statements", """\
-Convert conditional expression with unused result into conditional statement."""
-
+        return (
+            result,
+            "new_statements",
+            """\
+Convert conditional expression with unused result into conditional statement.""",
+        )
 
     def mayHaveSideEffectsBool(self):
         if self.getCondition().mayHaveSideEffectsBool():
@@ -223,15 +201,13 @@ Convert conditional expression with unused result into conditional statement."""
         yes_branch = self.getExpressionYes()
 
         # Handle branches that became empty behind our back
-        if yes_branch is not None and \
-           yes_branch.mayRaiseException(exception_type):
+        if yes_branch is not None and yes_branch.mayRaiseException(exception_type):
             return True
 
         no_branch = self.getExpressionNo()
 
         # Handle branches that became empty behind our back
-        if no_branch is not None and \
-           no_branch.mayRaiseException(exception_type):
+        if no_branch is not None and no_branch.mayRaiseException(exception_type):
             return True
 
         return False
@@ -250,49 +226,39 @@ Convert conditional expression with unused result into conditional statement."""
 
 
 class ExpressionConditionalBoolBase(ExpressionChildrenHavingBase):
-    named_children = (
-        "left",
-        "right"
-    )
+    named_children = ("left", "right")
 
     def __init__(self, left, right, source_ref):
         ExpressionChildrenHavingBase.__init__(
-            self,
-            values     = {
-                "left"  : left,
-                "right" : right,
-            },
-            source_ref = source_ref
+            self, values={"left": left, "right": right}, source_ref=source_ref
         )
 
-    getLeft = ExpressionChildrenHavingBase.childGetter(
-        "left"
-    )
-    getRight = ExpressionChildrenHavingBase.childGetter(
-        "right"
-    )
+    getLeft = ExpressionChildrenHavingBase.childGetter("left")
+    getRight = ExpressionChildrenHavingBase.childGetter("right")
 
     def computeExpressionRaw(self, trace_collection):
         # Query the truth value after the expression is evaluated, once it is
         # evaluated in onExpression, it is known.
-        trace_collection.onExpression(
-            expression = self.getLeft()
-        )
+        trace_collection.onExpression(expression=self.getLeft())
         left = self.getLeft()
 
         # No need to look any further, if the condition raises, the branches do
         # not matter at all.
         if left.willRaiseException(BaseException):
-            return left, "new_raise", """\
+            return (
+                left,
+                "new_raise",
+                """\
 Conditional %s statements already raises implicitly in condition, removing \
-branches.""" % self.conditional_kind
-
-        if not left.mayRaiseException(BaseException) and \
-           left.mayRaiseExceptionBool(BaseException):
-            trace_collection.onExceptionRaiseExit(
-                BaseException
+branches."""
+                % self.conditional_kind,
             )
 
+        if not left.mayRaiseException(BaseException) and left.mayRaiseExceptionBool(
+            BaseException
+        ):
+            trace_collection.onExceptionRaiseExit(BaseException)
+
         # Decide this based on truth value of condition.
         truth_value = left.getTruthValue()
 
@@ -307,13 +273,11 @@ branches.""" % self.conditional_kind
             # TODO: We now know that left evaluates and we should tell the
             # branch that.
             branch_yes_collection = TraceCollectionBranch(
-                parent = trace_collection,
-                name   = "boolean %s right branch" % self.conditional_kind
+                parent=trace_collection,
+                name="boolean %s right branch" % self.conditional_kind,
             )
 
-            branch_yes_collection.computeBranch(
-                branch = right
-            )
+            branch_yes_collection.computeBranch(branch=right)
 
             # May have just gone away, so fetch it again.
             right = self.getRight()
@@ -324,28 +288,23 @@ branches.""" % self.conditional_kind
         else:
             branch_yes_collection = None
 
-
         if branch_yes_collection:
             # Merge into parent execution.
-            trace_collection.mergeBranches(
-                branch_yes_collection,
-                None
-            )
+            trace_collection.mergeBranches(branch_yes_collection, None)
 
         if truth_value is truth_value_use_left:
             return (
                 left,
                 "new_expression",
-                "Conditional '%s' expression predicted to left value." % self.conditional_kind
+                "Conditional '%s' expression predicted to left value."
+                % self.conditional_kind,
             )
         elif truth_value is truth_value_use_right:
             return (
-                wrapExpressionWithNodeSideEffects(
-                    new_node = right,
-                    old_node = left
-                ),
+                wrapExpressionWithNodeSideEffects(new_node=right, old_node=left),
                 "new_expression",
-                "Conditional '%s' expression predicted right value." % self.conditional_kind
+                "Conditional '%s' expression predicted right value."
+                % self.conditional_kind,
             )
         else:
             return self, None, None
@@ -390,29 +349,29 @@ class ExpressionConditionalOR(ExpressionConditionalBoolBase):
 
     def __init__(self, left, right, source_ref):
         ExpressionConditionalBoolBase.__init__(
-            self,
-            left       = left,
-            right      = right,
-            source_ref = source_ref
+            self, left=left, right=right, source_ref=source_ref
         )
 
         self.conditional_kind = "or"
 
     def computeExpressionDrop(self, statement, trace_collection):
         result = makeStatementConditional(
-            condition  =  self.getLeft(),
-            yes_branch = None,
-            no_branch  = makeStatementExpressionOnlyReplacementNode(
-                expression = self.getRight(),
-                node       = self.getRight()
+            condition=self.getLeft(),
+            yes_branch=None,
+            no_branch=makeStatementExpressionOnlyReplacementNode(
+                expression=self.getRight(), node=self.getRight()
             ),
-            source_ref = self.source_ref
+            source_ref=self.source_ref,
         )
 
         del self.parent
 
-        return result, "new_statements", """\
-Convert conditional 'or' expression with unused result into conditional statement."""
+        return (
+            result,
+            "new_statements",
+            """\
+Convert conditional 'or' expression with unused result into conditional statement.""",
+        )
 
 
 class ExpressionConditionalAND(ExpressionConditionalBoolBase):
@@ -420,57 +379,52 @@ class ExpressionConditionalAND(ExpressionConditionalBoolBase):
 
     def __init__(self, left, right, source_ref):
         ExpressionConditionalBoolBase.__init__(
-            self,
-            left       = left,
-            right      = right,
-            source_ref = source_ref
+            self, left=left, right=right, source_ref=source_ref
         )
 
         self.conditional_kind = "and"
 
     def computeExpressionDrop(self, statement, trace_collection):
         result = makeStatementConditional(
-            condition  =  self.getLeft(),
-            no_branch  = None,
-            yes_branch = makeStatementExpressionOnlyReplacementNode(
-                expression = self.getRight(),
-                node       = self.getRight()
+            condition=self.getLeft(),
+            no_branch=None,
+            yes_branch=makeStatementExpressionOnlyReplacementNode(
+                expression=self.getRight(), node=self.getRight()
             ),
-            source_ref = self.source_ref
+            source_ref=self.source_ref,
         )
 
         del self.parent
 
-        return result, "new_statements", """\
-Convert conditional 'and' expression with unused result into conditional statement."""
+        return (
+            result,
+            "new_statements",
+            """\
+Convert conditional 'and' expression with unused result into conditional statement.""",
+        )
 
 
 class StatementConditional(StatementChildrenHavingBase):
     kind = "STATEMENT_CONDITIONAL"
 
-    named_children = (
-        "condition",
-        "yes_branch",
-        "no_branch"
-    )
+    named_children = ("condition", "yes_branch", "no_branch")
 
     checkers = {
-        "yes_branch" : checkStatementsSequenceOrNone,
-        "no_branch" : checkStatementsSequenceOrNone,
+        "yes_branch": checkStatementsSequenceOrNone,
+        "no_branch": checkStatementsSequenceOrNone,
     }
 
     def __init__(self, condition, yes_branch, no_branch, source_ref):
         StatementChildrenHavingBase.__init__(
             self,
-            values     = {
-                "condition"  : condition,
-                "yes_branch" : yes_branch,
-                "no_branch"  : no_branch
+            values={
+                "condition": condition,
+                "yes_branch": yes_branch,
+                "no_branch": no_branch,
             },
-            source_ref = source_ref
+            source_ref=source_ref,
         )
 
-
     getCondition = StatementChildrenHavingBase.childGetter("condition")
     getBranchYes = StatementChildrenHavingBase.childGetter("yes_branch")
     setBranchYes = StatementChildrenHavingBase.childSetter("yes_branch")
@@ -505,15 +459,13 @@ class StatementConditional(StatementChildrenHavingBase):
         yes_branch = self.getBranchYes()
 
         # Handle branches that became empty behind our back
-        if yes_branch is not None and \
-           yes_branch.mayRaiseException(exception_type):
+        if yes_branch is not None and yes_branch.mayRaiseException(exception_type):
             return True
 
         no_branch = self.getBranchNo()
 
         # Handle branches that became empty behind our back
-        if no_branch is not None and \
-           no_branch.mayRaiseException(exception_type):
+        if no_branch is not None and no_branch.mayRaiseException(exception_type):
             return True
 
         return False
@@ -530,15 +482,13 @@ class StatementConditional(StatementChildrenHavingBase):
         yes_branch = self.getBranchYes()
 
         # Handle branches that became empty behind our back
-        if yes_branch is not None and \
-           yes_branch.needsFrame():
+        if yes_branch is not None and yes_branch.needsFrame():
             return True
 
         no_branch = self.getBranchNo()
 
         # Handle branches that became empty behind our back
-        if no_branch is not None and \
-           no_branch.needsFrame():
+        if no_branch is not None and no_branch.needsFrame():
             return True
 
         return False
@@ -546,22 +496,23 @@ class StatementConditional(StatementChildrenHavingBase):
     def computeStatement(self, trace_collection):
         # This is rather complex stuff, pylint: disable=too-many-branches,too-many-statements
 
-        trace_collection.onExpression(
-            expression = self.getCondition()
-        )
+        trace_collection.onExpression(expression=self.getCondition())
         condition = self.getCondition()
 
         # No need to look any further, if the condition raises, the branches do
         # not matter at all.
         if condition.willRaiseException(BaseException):
             result = makeStatementExpressionOnlyReplacementNode(
-                expression = condition,
-                node       = self
+                expression=condition, node=self
             )
 
-            return result, "new_raise", """\
+            return (
+                result,
+                "new_raise",
+                """\
 Conditional statements already raises implicitly in condition, removing \
-branches."""
+branches.""",
+            )
 
         # Tell it we are evaluation it for boolean value only, it may demote
         # itself possibly.
@@ -595,9 +546,9 @@ branches."""
         # Consider to not remove branches that we know won't be taken.
         if yes_branch is not None and truth_value is False:
             trace_collection.signalChange(
-                tags       = "new_statements",
-                source_ref = yes_branch.source_ref,
-                message    = "Removed conditional branch not taken due to false condition value."
+                tags="new_statements",
+                source_ref=yes_branch.source_ref,
+                message="Removed conditional branch not taken due to false condition value.",
             )
 
             yes_branch.finalize()
@@ -606,9 +557,9 @@ branches."""
 
         if no_branch is not None and truth_value is True:
             trace_collection.signalChange(
-                tags       = "new_statements",
-                source_ref = no_branch.source_ref,
-                message    = "Removed 'else' branch not taken due to true condition value."
+                tags="new_statements",
+                source_ref=no_branch.source_ref,
+                message="Removed 'else' branch not taken due to true condition value.",
             )
 
             no_branch.finalize()
@@ -619,13 +570,10 @@ branches."""
         # relevant.
         if yes_branch is not None:
             branch_yes_collection = TraceCollectionBranch(
-                parent = trace_collection,
-                name   = "conditional yes branch",
+                parent=trace_collection, name="conditional yes branch"
             )
 
-            branch_yes_collection.computeBranch(
-                branch = yes_branch
-            )
+            branch_yes_collection.computeBranch(branch=yes_branch)
 
             # May have just gone away, so fetch it again.
             yes_branch = self.getBranchYes()
@@ -639,13 +587,10 @@ branches."""
         # Continue to execute for yes branch.
         if no_branch is not None:
             branch_no_collection = TraceCollectionBranch(
-                parent = trace_collection,
-                name   = "conditional no branch"
+                parent=trace_collection, name="conditional no branch"
             )
 
-            branch_no_collection.computeBranch(
-                branch = no_branch
-            )
+            branch_no_collection.computeBranch(branch=no_branch)
 
             # May have just gone away, so fetch it again.
             no_branch = self.getBranchNo()
@@ -663,10 +608,7 @@ branches."""
             if branch_no_collection is not None:
                 trace_collection.replaceBranch(branch_no_collection)
         else:
-            trace_collection.mergeBranches(
-                branch_yes_collection,
-                branch_no_collection
-            )
+            trace_collection.mergeBranches(branch_yes_collection, branch_no_collection)
 
         # Both branches may have become empty, which case, the statement needs
         # not remain.
@@ -674,27 +616,33 @@ branches."""
             # Need to keep the boolean check.
             if truth_value is None:
                 condition = ExpressionBuiltinBool(
-                    value      = condition,
-                    source_ref = condition.getSourceReference()
+                    value=condition, source_ref=condition.getSourceReference()
                 )
 
             if condition.mayHaveSideEffects():
                 # With both branches eliminated, the condition remains as a side
                 # effect.
                 result = makeStatementExpressionOnlyReplacementNode(
-                    expression = condition,
-                    node       = self
+                    expression=condition, node=self
                 )
 
                 del self.parent
 
-                return result, "new_statements", """\
-Both branches have no effect, reduced to evaluate condition."""
+                return (
+                    result,
+                    "new_statements",
+                    """\
+Both branches have no effect, reduced to evaluate condition.""",
+                )
             else:
                 self.finalize()
 
-                return None, "new_statements", """\
-Removed conditional statement without effect."""
+                return (
+                    None,
+                    "new_statements",
+                    """\
+Removed conditional statement without effect.""",
+                )
 
         # Note: Checking the condition late, so that the surviving branch got
         # processed already. Returning without doing that, will corrupt the SSA
@@ -715,15 +663,20 @@ Removed conditional statement without effect."""
                     yes_branch.finalize()
 
             new_statement = wrapStatementWithSideEffects(
-                new_node   = new_statement,
-                old_node   = condition,
-                allow_none = True # surviving branch may empty
+                new_node=new_statement,
+                old_node=condition,
+                allow_none=True,  # surviving branch may empty
             )
 
             del self.parent
 
-            return new_statement, "new_statements", """\
-Condition for branch statement was predicted to be always %s.""" % choice
+            return (
+                new_statement,
+                "new_statements",
+                """\
+Condition for branch statement was predicted to be always %s."""
+                % choice,
+            )
 
         # If there is no "yes" branch, remove that. Maybe a bad idea though.
         if yes_branch is None:
@@ -732,19 +685,22 @@ Condition for branch statement was predicted to be always %s.""" % choice
             assert no_branch is not None
 
             new_statement = makeStatementConditional(
-                condition  = ExpressionOperationNOT(
-                    operand    = condition,
-                    source_ref = condition.getSourceReference()
+                condition=ExpressionOperationNOT(
+                    operand=condition, source_ref=condition.getSourceReference()
                 ),
-                yes_branch = no_branch,
-                no_branch  = None,
-                source_ref = self.getSourceReference()
+                yes_branch=no_branch,
+                no_branch=None,
+                source_ref=self.getSourceReference(),
             )
 
             del self.parent
 
-            return new_statement, "new_statements", """\
-Empty 'yes' branch for conditional statement treated with inverted condition check."""
+            return (
+                new_statement,
+                "new_statements",
+                """\
+Empty 'yes' branch for conditional statement treated with inverted condition check.""",
+            )
 
         return self, None, None
 
@@ -774,7 +730,6 @@ Empty 'yes' branch for conditional statement treated with inverted condition che
 
         return False
 
-
     def mayContinue(self):
         yes_branch = self.getBranchYes()
 
@@ -800,28 +755,20 @@ def makeStatementConditional(condition, yes_branch, no_branch, source_ref):
 
     if yes_branch is None:
         condition = ExpressionOperationNOT(
-            operand    = condition,
-            source_ref = condition.getSourceReference()
+            operand=condition, source_ref=condition.getSourceReference()
         )
 
         yes_branch, no_branch = no_branch, yes_branch
 
     if yes_branch is not None and not yes_branch.isStatementsSequence():
-        yes_branch = StatementsSequence(
-            statements = (yes_branch,),
-            source_ref = source_ref
-        )
+        yes_branch = StatementsSequence(statements=(yes_branch,), source_ref=source_ref)
 
     if no_branch is not None and not no_branch.isStatementsSequence():
-        no_branch = StatementsSequence(
-            statements = (no_branch,),
-            source_ref = source_ref
-        )
+        no_branch = StatementsSequence(statements=(no_branch,), source_ref=source_ref)
 
     return StatementConditional(
-        condition  = condition,
-        yes_branch = yes_branch,
-        no_branch  = no_branch,
-        source_ref = source_ref
-
+        condition=condition,
+        yes_branch=yes_branch,
+        no_branch=no_branch,
+        source_ref=source_ref,
     )
