@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -34,34 +34,40 @@ _future_annotations_default = python_version >= 400
 
 
 class FutureSpec(object):
-    __slots__ = ("future_division", "unicode_literals", "absolute_import",
-                 "future_print", "barry_bdfl", "generator_stop",
-                 "future_annotations")
+    __slots__ = (
+        "future_division",
+        "unicode_literals",
+        "absolute_import",
+        "future_print",
+        "barry_bdfl",
+        "generator_stop",
+        "future_annotations",
+    )
 
     @counted_init
     def __init__(self):
-        self.future_division    = _future_division_default
-        self.unicode_literals   = False
-        self.absolute_import    = _future_absolute_import_default
-        self.future_print       = False
-        self.barry_bdfl         = False
-        self.generator_stop     = _future_generator_stop_default
+        self.future_division = _future_division_default
+        self.unicode_literals = False
+        self.absolute_import = _future_absolute_import_default
+        self.future_print = False
+        self.barry_bdfl = False
+        self.generator_stop = _future_generator_stop_default
         self.future_annotations = _future_annotations_default
 
     __del__ = counted_del()
 
     def __repr__(self):
-        return "<FutureSpec %s>" % ','.join(self.asFlags())
+        return "<FutureSpec %s>" % ",".join(self.asFlags())
 
     def clone(self):
         result = FutureSpec()
 
-        result.future_division    = self.future_division
-        result.unicode_literals   = self.unicode_literals
-        result.absolute_import    = self.absolute_import
-        result.future_print       = self.future_print
-        result.barry_bdfl         = self.barry_bdfl
-        result.generator_stop     = self.generator_stop
+        result.future_division = self.future_division
+        result.unicode_literals = self.unicode_literals
+        result.absolute_import = self.absolute_import
+        result.future_print = self.future_print
+        result.barry_bdfl = self.barry_bdfl
+        result.generator_stop = self.generator_stop
         result.future_annotations = result.future_annotations
 
         return result
@@ -136,7 +142,7 @@ class FutureSpec(object):
 
 
 def fromFlags(flags):
-    flags = flags.split(',')
+    flags = flags.split(",")
     if "" in flags:
         flags.remove("")
 
