@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -29,24 +29,28 @@ from logging import debug
 from nuitka import Tracing, Variables
 from nuitka.__past__ import iterItems  # Python3 compatibility.
 from nuitka.containers.oset import OrderedSet
-from nuitka.importing.ImportCache import (
-    getImportedModuleByName,
-    isImportedModuleByName
-)
+from nuitka.importing.ImportCache import getImportedModuleByNameAndPath
 from nuitka.ModuleRegistry import addUsedModule
 from nuitka.nodes.NodeMakingHelpers import getComputationResult
-from nuitka.nodes.shapes.BuiltinTypeShapes import ShapeTypeDict
+from nuitka.nodes.shapes.BuiltinTypeShapes import (
+    ShapeTypeDict,
+    ShapeTypeInt,
+    ShapeTypeIntOrLong,
+    ShapeTypeLong,
+)
 from nuitka.PythonVersions import python_version
 from nuitka.tree.SourceReading import readSourceLine
+from nuitka.utils.FileOperations import relpath
 from nuitka.utils.InstanceCounters import counted_del, counted_init
 
 from .ValueTraces import (
     ValueTraceAssign,
     ValueTraceInit,
-    ValueTraceLoopMerge,
+    ValueTraceLoopComplete,
+    ValueTraceLoopInitial,
     ValueTraceMerge,
     ValueTraceUninit,
-    ValueTraceUnknown
+    ValueTraceUnknown,
 )
 
 signalChange = None
@@ -70,8 +74,7 @@ class CollectionTracingMixin(object):
         """
 
         return self.getVariableTrace(
-            variable = variable,
-            version  = self._getCurrentVariableVersion(variable)
+            variable=variable, version=self._getCurrentVariableVersion(variable)
         )
 
     def markCurrentVariableTrace(self, variable, version):
@@ -93,38 +96,45 @@ class CollectionTracingMixin(object):
         return self.variable_actives.keys()
 
     def markActiveVariableAsUnknown(self, variable):
-        current = self.getVariableCurrentTrace(
-            variable = variable,
-        )
+        current = self.getVariableCurrentTrace(variable=variable)
 
         if not current.isUnknownTrace():
             version = variable.allocateTargetNumber()
 
             self.addVariableTrace(
-                variable = variable,
-                version  = version,
-                trace    = ValueTraceUnknown(
-                    owner    = self.owner,
-                    previous = current
-                )
+                variable=variable,
+                version=version,
+                trace=ValueTraceUnknown(owner=self.owner, previous=current),
             )
 
             self.markCurrentVariableTrace(variable, version)
 
-    def markActiveVariableAsLoopMerge(self, variable):
-        current = self.getVariableCurrentTrace(
-            variable = variable,
-        )
+    def markActiveVariableAsLoopMerge(self, variable, shapes, initial):
+        current = self.getVariableCurrentTrace(variable=variable)
 
         version = variable.allocateTargetNumber()
 
-        result = ValueTraceLoopMerge(current)
+        current_shape = current.getTypeShape()
 
-        self.addVariableTrace(
-            variable = variable,
-            version  = version,
-            trace    = result
-        )
+        if current_shape not in shapes:
+            shapes = set(shapes)
+            shapes.add(current_shape)
+
+        if python_version < 300:
+            if ShapeTypeIntOrLong in shapes:
+                if ShapeTypeInt in shapes:
+                    shapes.discard(ShapeTypeInt)
+                if ShapeTypeLong in shapes:
+                    shapes.discard(ShapeTypeLong)
+
+        # print(initial, shapes)
+
+        if initial:
+            result = ValueTraceLoopInitial(current, shapes)
+        else:
+            result = ValueTraceLoopComplete(current, shapes)
+
+        self.addVariableTrace(variable=variable, version=version, trace=result)
 
         self.markCurrentVariableTrace(variable, version)
 
@@ -160,44 +170,35 @@ class CollectionStartpointMixin(object):
     def getLoopBreakCollections(self):
         return self.break_collections
 
-    def onLoopBreak(self, collection = None):
+    def onLoopBreak(self, collection=None):
         if collection is None:
             collection = self
 
         self.break_collections.append(
-            TraceCollectionBranch(
-                parent = collection,
-                name   = "loop break"
-            )
+            TraceCollectionBranch(parent=collection, name="loop break")
         )
 
     def getLoopContinueCollections(self):
         return self.continue_collections
 
-    def onLoopContinue(self, collection = None):
+    def onLoopContinue(self, collection=None):
         if collection is None:
             collection = self
 
         self.continue_collections.append(
-            TraceCollectionBranch(
-                parent = collection,
-                name   = "loop continue"
-            )
+            TraceCollectionBranch(parent=collection, name="loop continue")
         )
 
-    def onFunctionReturn(self, collection = None):
+    def onFunctionReturn(self, collection=None):
         if collection is None:
             collection = self
 
         if self.return_collections is not None:
             self.return_collections.append(
-                TraceCollectionBranch(
-                    parent = collection,
-                    name   = "return"
-                )
+                TraceCollectionBranch(parent=collection, name="return")
             )
 
-    def onExceptionRaiseExit(self, raisable_exceptions, collection = None):
+    def onExceptionRaiseExit(self, raisable_exceptions, collection=None):
         # TODO: We might want to track per exception, pylint: disable=unused-argument
 
         if collection is None:
@@ -205,10 +206,7 @@ class CollectionStartpointMixin(object):
 
         if self.exception_collections is not None:
             self.exception_collections.append(
-                TraceCollectionBranch(
-                    parent = collection,
-                    name   = "exception"
-                )
+                TraceCollectionBranch(parent=collection, name="exception")
             )
 
     def getFunctionReturnCollections(self):
@@ -251,7 +249,8 @@ class CollectionStartpointMixin(object):
         self.addVariableTrace(variable, version, trace_merge)
 
         return version
-#         return version, trace_merge
+
+    #         return version, trace_merge
 
     def dumpTraces(self):
         debug("Constraint collection state: %s", self)
@@ -269,41 +268,23 @@ class CollectionStartpointMixin(object):
         Tracing.printSeparator()
 
     def initVariableUnknown(self, variable):
-        trace = ValueTraceUnknown(
-            owner    = self.owner,
-            previous = None
-        )
+        trace = ValueTraceUnknown(owner=self.owner, previous=None)
 
-        self.addVariableTrace(
-            variable = variable,
-            version  = 0,
-            trace    = trace
-        )
+        self.addVariableTrace(variable=variable, version=0, trace=trace)
 
         return trace
 
     def _initVariableInit(self, variable):
         trace = ValueTraceInit(self.owner)
 
-        self.addVariableTrace(
-            variable = variable,
-            version  = 0,
-            trace    = trace
-        )
+        self.addVariableTrace(variable=variable, version=0, trace=trace)
 
         return trace
 
     def _initVariableUninit(self, variable):
-        trace = ValueTraceUninit(
-            owner    = self.owner,
-            previous = None
-        )
+        trace = ValueTraceUninit(owner=self.owner, previous=None)
 
-        self.addVariableTrace(
-            variable = variable,
-            version  = 0,
-            trace    = trace
-        )
+        self.addVariableTrace(variable=variable, version=0, trace=trace)
 
         return trace
 
@@ -311,8 +292,9 @@ class CollectionStartpointMixin(object):
         Variables.updateVariablesFromCollection(old_collection, self)
 
     @contextlib.contextmanager
-    def makeAbortStackContext(self, catch_breaks, catch_continues,
-                              catch_returns, catch_exceptions):
+    def makeAbortStackContext(
+        self, catch_breaks, catch_continues, catch_returns, catch_exceptions
+    ):
         if catch_breaks:
             old_break_collections = self.break_collections
             self.break_collections = []
@@ -371,7 +353,6 @@ class CollectionStartpointMixin(object):
             for variable in locals_scope.variables.values():
                 self.markActiveVariableAsUnknown(variable)
 
-
         for variable in self.getActiveVariables():
             if variable.isTempVariable() or variable.isModuleVariable():
                 continue
@@ -379,7 +360,6 @@ class CollectionStartpointMixin(object):
             self.markActiveVariableAsUnknown(variable)
 
 
-
 class TraceCollectionBase(CollectionTracingMixin):
     __del__ = counted_del()
 
@@ -395,11 +375,7 @@ class TraceCollectionBase(CollectionTracingMixin):
         self.value_states = {}
 
     def __repr__(self):
-        return "<%s for %s at 0x%x>" % (
-            self.__class__.__name__,
-            self.name,
-            id(self)
-        )
+        return "<%s for %s at 0x%x>" % (self.__class__.__name__, self.name, id(self))
 
     def getOwner(self):
         return self.owner
@@ -409,8 +385,8 @@ class TraceCollectionBase(CollectionTracingMixin):
         # This is monkey patched from another module.
         signalChange(tags, source_ref, message)
 
-    def onUsedModule(self, module_name):
-        return self.parent.onUsedModule(module_name)
+    def onUsedModule(self, module_name, module_relpath):
+        return self.parent.onUsedModule(module_name, module_relpath)
 
     @staticmethod
     def mustAlias(a, b):
@@ -441,12 +417,12 @@ class TraceCollectionBase(CollectionTracingMixin):
 
                 self.markActiveVariableAsUnknown(variable)
 
-            elif variable.isLocalVariable() and \
-                (python_version >= 300 or variable.isSharedTechnically() is not False):
-                # TODO: Could be limited to shared variables that are actually
-                # written to. Most of the time, that won't be the case.
-
-                self.markActiveVariableAsUnknown(variable)
+            elif variable.isLocalVariable():
+                if (
+                    python_version >= 300
+                    and variable.hasWritesOutsideOf(self.owner) is not False
+                ):
+                    self.markActiveVariableAsUnknown(variable)
 
     def removeAllKnowledge(self):
         self.markActiveVariablesAsUnknown()
@@ -465,18 +441,12 @@ class TraceCollectionBase(CollectionTracingMixin):
 
     def onVariableSet(self, variable, version, assign_node):
         variable_trace = ValueTraceAssign(
-            owner       = self.owner,
-            assign_node = assign_node,
-            previous    = self.getVariableCurrentTrace(
-                variable = variable
-            )
+            owner=self.owner,
+            assign_node=assign_node,
+            previous=self.getVariableCurrentTrace(variable=variable),
         )
 
-        self.addVariableTrace(
-            variable = variable,
-            version  = version,
-            trace    = variable_trace
-        )
+        self.addVariableTrace(variable=variable, version=version, trace=variable_trace)
 
         # Make references point to it.
         self.markCurrentVariableTrace(variable, version)
@@ -488,17 +458,10 @@ class TraceCollectionBase(CollectionTracingMixin):
         # remember the delete of the current
         old_trace = self.getVariableCurrentTrace(variable)
 
-        variable_trace = ValueTraceUninit(
-            owner    = self.owner,
-            previous = old_trace
-        )
+        variable_trace = ValueTraceUninit(owner=self.owner, previous=old_trace)
 
         # Assign to not initialized again.
-        self.addVariableTrace(
-            variable = variable,
-            version  = version,
-            trace    = variable_trace
-        )
+        self.addVariableTrace(variable=variable, version=version, trace=variable_trace)
 
         # Make references point to it.
         self.markCurrentVariableTrace(variable, version)
@@ -510,32 +473,31 @@ class TraceCollectionBase(CollectionTracingMixin):
 
         result = []
 
-        include_closure = locals_owner.isExpressionFunctionBody() and \
-                          not locals_owner.isUnoptimized()
+        include_closure = (
+            locals_owner.isExpressionFunctionBody() and not locals_owner.isUnoptimized()
+        )
 
         for variable in self.getActiveVariables():
-            if variable.isLocalVariable() and \
-               (variable.getOwner() is locals_owner or
-                include_closure and locals_owner.hasClosureVariable(variable)) and \
-               variable.getName() != ".0":
-                variable_trace = self.getVariableCurrentTrace(
-                    variable
+            if (
+                variable.isLocalVariable()
+                and (
+                    variable.getOwner() is locals_owner
+                    or include_closure
+                    and locals_owner.hasClosureVariable(variable)
                 )
+                and variable.getName() != ".0"
+            ):
+                variable_trace = self.getVariableCurrentTrace(variable)
 
                 variable_trace.addNameUsage()
-                result.append(
-                    (
-                        variable,
-                        variable_trace
-                    )
-                )
+                result.append((variable, variable_trace))
 
         return result
 
     def onVariableContentEscapes(self, variable):
         self.getVariableCurrentTrace(variable).onValueEscape()
 
-    def onExpression(self, expression, allow_none = False):
+    def onExpression(self, expression, allow_none=False):
         if expression is None and allow_none:
             return None
 
@@ -546,9 +508,7 @@ class TraceCollectionBase(CollectionTracingMixin):
 
         # Now compute this expression, allowing it to replace itself with
         # something else as part of a local peep hole optimization.
-        r = expression.computeExpressionRaw(
-            trace_collection = self
-        )
+        r = expression.computeExpressionRaw(trace_collection=self)
         assert type(r) is tuple, expression
 
         new_node, change_tags, change_desc = r
@@ -556,11 +516,7 @@ class TraceCollectionBase(CollectionTracingMixin):
         if change_tags is not None:
             # This is mostly for tracing and indication that a change occurred
             # and it may be interesting to look again.
-            self.signalChange(
-                change_tags,
-                expression.getSourceReference(),
-                change_desc
-            )
+            self.signalChange(change_tags, expression.getSourceReference(), change_desc)
 
         if new_node is not expression:
             parent.replaceChild(expression, new_node)
@@ -571,23 +527,21 @@ class TraceCollectionBase(CollectionTracingMixin):
         try:
             assert statement.isStatement(), statement
 
-            new_statement, change_tags, change_desc = \
-              statement.computeStatement(self)
+            new_statement, change_tags, change_desc = statement.computeStatement(self)
 
             # print new_statement, change_tags, change_desc
             if new_statement is not statement:
                 self.signalChange(
-                    change_tags,
-                    statement.getSourceReference(),
-                    change_desc
+                    change_tags, statement.getSourceReference(), change_desc
                 )
 
             return new_statement
         except Exception:
             Tracing.printError(
-                "Problem with statement at %s:\n-> %s" % (
+                "Problem with statement at %s:\n-> %s"
+                % (
                     statement.source_ref.getAsString(),
-                    readSourceLine(statement.source_ref)
+                    readSourceLine(statement.source_ref),
                 )
             )
             raise
@@ -607,11 +561,11 @@ class TraceCollectionBase(CollectionTracingMixin):
             # Handle one branch case, we need to merge versions backwards as
             # they may make themselves obsolete.
             return self.mergeMultipleBranches(
-                collections = (self, collection_yes or collection_no)
+                collections=(self, collection_yes or collection_no)
             )
         else:
             return self.mergeMultipleBranches(
-                collections = (collection_yes, collection_no)
+                collections=(collection_yes, collection_no)
             )
 
     def mergeMultipleBranches(self, collections):
@@ -639,54 +593,53 @@ class TraceCollectionBase(CollectionTracingMixin):
 
         self.variable_actives = {}
 
-#         merge_traces = None
+        #         merge_traces = None
 
         for variable, versions in iterItems(variable_versions):
             if len(versions) == 1:
                 version, = versions
             else:
                 version = self.addVariableMergeMultipleTrace(
-                    variable = variable,
-                    traces   = [
-                        self.getVariableTrace(variable, version)
-                        for version in
-                        versions
-                    ]
+                    variable=variable,
+                    traces=[
+                        self.getVariableTrace(variable, version) for version in versions
+                    ],
                 )
 
-#                 if merge_traces is None:
-#                     merge_traces = [trace_merge]
-#                 else:
-#                     merge_traces.append(trace_merge)
+            #                 if merge_traces is None:
+            #                     merge_traces = [trace_merge]
+            #                 else:
+            #                     merge_traces.append(trace_merge)
 
             self.markCurrentVariableTrace(variable, version)
 
         # Return "None", or turn the list into a tuple for memory savings.
-#         return merge_traces and tuple(merge_traces)
+
+    #         return merge_traces and tuple(merge_traces)
 
     def replaceBranch(self, collection_replace):
         self.variable_actives.update(collection_replace.variable_actives)
         collection_replace.variable_actives = None
 
-    def onLoopBreak(self, collection = None):
+    def onLoopBreak(self, collection=None):
         if collection is None:
             collection = self
 
         return self.parent.onLoopBreak(collection)
 
-    def onLoopContinue(self, collection = None):
+    def onLoopContinue(self, collection=None):
         if collection is None:
             collection = self
 
         return self.parent.onLoopContinue(collection)
 
-    def onFunctionReturn(self, collection = None):
+    def onFunctionReturn(self, collection=None):
         if collection is None:
             collection = self
 
         return self.parent.onFunctionReturn(collection)
 
-    def onExceptionRaiseExit(self, raisable_exceptions, collection = None):
+    def onExceptionRaiseExit(self, raisable_exceptions, collection=None):
         if collection is None:
             collection = self
 
@@ -704,13 +657,14 @@ class TraceCollectionBase(CollectionTracingMixin):
     def getExceptionRaiseCollections(self):
         return self.parent.getExceptionRaiseCollections()
 
-    def makeAbortStackContext(self, catch_breaks, catch_continues,
-                              catch_returns, catch_exceptions):
+    def makeAbortStackContext(
+        self, catch_breaks, catch_continues, catch_returns, catch_exceptions
+    ):
         return self.parent.makeAbortStackContext(
-            catch_breaks     = catch_breaks,
-            catch_continues  = catch_continues,
-            catch_returns    = catch_returns,
-            catch_exceptions = catch_exceptions
+            catch_breaks=catch_breaks,
+            catch_continues=catch_continues,
+            catch_returns=catch_returns,
+            catch_exceptions=catch_exceptions,
         )
 
     def onLocalsDictEscaped(self, locals_scope):
@@ -718,9 +672,7 @@ class TraceCollectionBase(CollectionTracingMixin):
 
     def getCompileTimeComputationResult(self, node, computation, description):
         new_node, change_tags, message = getComputationResult(
-            node        = node,
-            computation = computation,
-            description = description
+            node=node, computation=computation, description=description
         )
 
         if change_tags == "new_raise":
@@ -749,27 +701,18 @@ class TraceCollectionBase(CollectionTracingMixin):
 
 class TraceCollectionBranch(TraceCollectionBase):
     def __init__(self, name, parent):
-        TraceCollectionBase.__init__(
-            self,
-            owner  = parent.owner,
-            name   = name,
-            parent = parent
-        )
+        TraceCollectionBase.__init__(self, owner=parent.owner, name=name, parent=parent)
 
         self.variable_actives = dict(parent.variable_actives)
 
     def computeBranch(self, branch):
         if branch.isStatementsSequence():
-            result = branch.computeStatementsSequence(
-                trace_collection = self
-            )
+            result = branch.computeStatementsSequence(trace_collection=self)
 
             if result is not branch:
                 branch.parent.replaceChild(branch, result)
         else:
-            self.onExpression(
-                expression = branch
-            )
+            self.onExpression(expression=branch)
 
     def initVariable(self, variable):
         variable_trace = self.parent.initVariable(variable)
@@ -795,21 +738,22 @@ class TraceCollectionBranch(TraceCollectionBase):
         Tracing.printSeparator()
 
 
-class TraceCollectionFunction(CollectionStartpointMixin,
-                              TraceCollectionBase):
+class TraceCollectionFunction(CollectionStartpointMixin, TraceCollectionBase):
     def __init__(self, parent, function_body):
-        assert function_body.isExpressionFunctionBody() or \
-               function_body.isExpressionGeneratorObjectBody() or \
-               function_body.isExpressionCoroutineObjectBody() or \
-               function_body.isExpressionAsyncgenObjectBody(), function_body
+        assert (
+            function_body.isExpressionFunctionBody()
+            or function_body.isExpressionGeneratorObjectBody()
+            or function_body.isExpressionCoroutineObjectBody()
+            or function_body.isExpressionAsyncgenObjectBody()
+        ), function_body
 
         CollectionStartpointMixin.__init__(self)
 
         TraceCollectionBase.__init__(
             self,
-            owner  = function_body,
-            name   = "collection_" + function_body.getCodeName(),
-            parent = parent
+            owner=function_body,
+            name="collection_" + function_body.getCodeName(),
+            parent=parent,
         )
 
         if function_body.isExpressionFunctionBody():
@@ -832,30 +776,29 @@ class TraceCollectionFunction(CollectionStartpointMixin,
                 function_body.locals_scope = None
 
 
-class TraceCollectionModule(CollectionStartpointMixin,
-                            TraceCollectionBase):
+class TraceCollectionModule(CollectionStartpointMixin, TraceCollectionBase):
     def __init__(self, module):
         assert module.isCompiledPythonModule(), module
 
         CollectionStartpointMixin.__init__(self)
 
         TraceCollectionBase.__init__(
-            self,
-            owner  = module,
-            name   = "module:" + module.getFullName(),
-            parent = None
+            self, owner=module, name="module:" + module.getFullName(), parent=None
         )
 
         self.used_modules = OrderedSet()
 
-    def onUsedModule(self, module_name):
+    def onUsedModule(self, module_name, module_relpath):
         assert type(module_name) is str, module_name
 
-        self.used_modules.add(module_name)
+        # TODO: Make users provide this through a method that has already
+        # done this.
+        module_relpath = relpath(module_relpath)
 
-        if isImportedModuleByName(module_name):
-            module = getImportedModuleByName(module_name)
-            addUsedModule(module)
+        self.used_modules.add((module_name, module_relpath))
+
+        module = getImportedModuleByNameAndPath(module_name, module_relpath)
+        addUsedModule(module)
 
     def getUsedModules(self):
         return self.used_modules
