@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -38,24 +38,26 @@ from nuitka.ModuleRegistry import addUsedModule
 from nuitka.PythonVersions import python_version
 
 from .PluginBase import UserPluginBase, post_modules, pre_modules
+from .standard.ConsiderPyLintAnnotationsPlugin import (
+    NuitkaPluginDetectorPylintEclipseAnnotations,
+    NuitkaPluginPylintEclipseAnnotations,
+)
 from .standard.DataFileCollectorPlugin import NuitkaPluginDataFileCollector
 from .standard.ImplicitImports import NuitkaPluginPopularImplicitImports
-from .standard.PmwPlugin import NuitkaPluginDetectorPmw, NuitkaPluginPmw
-
-from .standard.ConsiderPyLintAnnotationsPlugin import (  # isort:skip
-    NuitkaPluginDetectorPylintEclipseAnnotations,
-    NuitkaPluginPylintEclipseAnnotations
-)
-from .standard.MultiprocessingPlugin import (  # isort:skip
+from .standard.MultiprocessingPlugin import (
     NuitkaPluginDetectorMultiprocessingWorkarounds,
-    NuitkaPluginMultiprocessingWorkarounds
+    NuitkaPluginMultiprocessingWorkarounds,
 )
-from .standard.PySidePyQtPlugin import (  # isort:skip
+from .standard.NumpyPlugin import NumpyPlugin, NumpyPluginDetector
+from .standard.PmwPlugin import NuitkaPluginDetectorPmw, NuitkaPluginPmw
+from .standard.PySidePyQtPlugin import (
     NuitkaPluginDetectorPyQtPySidePlugins,
-    NuitkaPluginPyQtPySidePlugins
+    NuitkaPluginPyQtPySidePlugins,
 )
+from .standard.TkinterPlugin import TkinterPlugin, TkinterPluginDetector
+
 # The standard plug-ins have their list hard-coded here. User plug-ins will
-# be scanned later, TODO.
+# be scanned later.
 
 active_plugin_list = [
     NuitkaPluginPopularImplicitImports(),
@@ -66,16 +68,22 @@ active_plugin_list = [
 # add your class here. The second one is a detector, which is supposed to give
 # a missing plug-in message, should it find the condition to make it useful.
 optional_plugin_classes = (
-    (NuitkaPluginMultiprocessingWorkarounds, NuitkaPluginDetectorMultiprocessingWorkarounds),
+    (
+        NuitkaPluginMultiprocessingWorkarounds,
+        NuitkaPluginDetectorMultiprocessingWorkarounds,
+    ),
     (NuitkaPluginPyQtPySidePlugins, NuitkaPluginDetectorPyQtPySidePlugins),
-    (NuitkaPluginPylintEclipseAnnotations, NuitkaPluginDetectorPylintEclipseAnnotations),
+    (
+        NuitkaPluginPylintEclipseAnnotations,
+        NuitkaPluginDetectorPylintEclipseAnnotations,
+    ),
     (NuitkaPluginPmw, NuitkaPluginDetectorPmw),
+    (TkinterPlugin, TkinterPluginDetector),
+    (NumpyPlugin, NumpyPluginDetector),
 )
 
 plugin_name2plugin_classes = dict(
-    (plugin[0].plugin_name, plugin)
-    for plugin in
-    optional_plugin_classes
+    (plugin[0].plugin_name, plugin) for plugin in optional_plugin_classes
 )
 
 
@@ -102,18 +110,14 @@ class Plugins(object):
             for extra_dll in plugin.considerExtraDlls(dist_dir, module):
                 if not os.path.isfile(extra_dll[0]):
                     sys.exit(
-                        "Error, attempting to copy plugin determinted filename %r for module %r that is not a file." % (
-                            extra_dll[0],
-                            module.getFullName()
-                        )
+                        "Error, attempting to copy plugin determinted filename %r for module %r that is not a file."
+                        % (extra_dll[0], module.getFullName())
                     )
 
                 if not os.path.isfile(extra_dll[1]):
                     sys.exit(
-                        "Error, copied filename %r for module %r that is not a file." % (
-                            extra_dll[1],
-                            module.getFullName()
-                        )
+                        "Error, copied filename %r for module %r that is not a file."
+                        % (extra_dll[1], module.getFullName())
                     )
 
                 result.append(extra_dll)
@@ -127,7 +131,9 @@ class Plugins(object):
         result = []
 
         for plugin in active_plugin_list:
-            for removed_dll in plugin.removeDllDependencies(dll_filename, dll_filenames):
+            for removed_dll in plugin.removeDllDependencies(
+                dll_filename, dll_filenames
+            ):
                 result.append(removed_dll)
 
         return result
@@ -160,7 +166,9 @@ class Plugins(object):
         assert type(source_code) is str
 
         for plugin in active_plugin_list:
-            source_code = plugin.onFrozenModuleSourceCode(module_name, is_package, source_code)
+            source_code = plugin.onFrozenModuleSourceCode(
+                module_name, is_package, source_code
+            )
             assert type(source_code) is str
 
         return source_code
@@ -177,16 +185,12 @@ class Plugins(object):
         return bytecode
 
     @staticmethod
-    def onModuleEncounter(module_filename, module_name, module_package,
-                          module_kind):
+    def onModuleEncounter(module_filename, module_name, module_package, module_kind):
         result = False
 
         for plugin in active_plugin_list:
             must_recurse = plugin.onModuleEncounter(
-                module_filename,
-                module_name,
-                module_package,
-                module_kind
+                module_filename, module_name, module_package, module_kind
             )
 
             result = result or must_recurse
@@ -221,7 +225,9 @@ class Plugins(object):
         source_ref = importing.getSourceReference()
 
         for plugin in active_plugin_list:
-            if plugin.suppressUnknownImportWarning(importing_module, module_name, source_ref):
+            if plugin.suppressUnknownImportWarning(
+                importing_module, module_name, source_ref
+            ):
                 return True
 
         return False
@@ -253,7 +259,8 @@ def isObjectAUserPluginBaseClass(obj):
 
 
 def importFilePy3NewWay(filename):
-    import importlib.util   # @UnresolvedImport pylint: disable=I0021,import-error,no-name-in-module
+    import importlib.util  # @UnresolvedImport pylint: disable=I0021,import-error,no-name-in-module
+
     spec = importlib.util.spec_from_file_location(filename, filename)
     user_plugin_module = importlib.util.module_from_spec(spec)
     spec.loader.exec_module(user_plugin_module)
@@ -261,21 +268,27 @@ def importFilePy3NewWay(filename):
 
 
 def importFilePy3OldWay(filename):
-    from importlib.machinery import SourceFileLoader  # @UnresolvedImport pylint: disable=I0021,import-error,no-name-in-module
-    return SourceFileLoader(filename, filename).load_module(filename)   # pylint: disable=I0021,deprecated-method
+    from importlib.machinery import (  # pylint: disable=I0021,import-error,no-name-in-module
+        SourceFileLoader,  # @UnresolvedImport
+    )
+
+    # pylint: disable=I0021,deprecated-method
+    return SourceFileLoader(filename, filename).load_module(filename)
 
 
 def importFilePy2(filename):
     import imp
+
     return imp.load_source(filename, filename)
 
 
 def importFile(filename):
     if python_version < 300:
         return importFilePy2(filename)
-    if python_version < 350:
+    elif python_version < 350:
         return importFilePy3OldWay(filename)
-    return importFilePy3NewWay(filename)
+    else:
+        return importFilePy3NewWay(filename)
 
 
 def importUserPlugins():
@@ -300,22 +313,25 @@ def initPlugins():
         if plugin_name not in plugin_name2plugin_classes:
             sys.exit("Error, unknown plug-in '%s' referenced." % plugin_name)
 
-        if plugin_name in Options.getPluginsEnabled() and \
-           plugin_name in Options.getPluginsDisabled():
+        if (
+            plugin_name in Options.getPluginsEnabled()
+            and plugin_name in Options.getPluginsDisabled()
+        ):
             sys.exit("Error, conflicting enable/disable of plug-in '%s'." % plugin_name)
 
-    for plugin_name, (plugin_class, plugin_detector) in plugin_name2plugin_classes.items():
+    for (
+        plugin_name,
+        (plugin_class, plugin_detector),
+    ) in plugin_name2plugin_classes.items():
         if plugin_name in Options.getPluginsEnabled():
-            active_plugin_list.append(
-                plugin_class()
-            )
+            active_plugin_list.append(plugin_class())
         elif plugin_name not in Options.getPluginsDisabled():
-            if plugin_detector is not None \
-               and Options.shallDetectMissingPlugins() and \
-               plugin_detector.isRelevant():
-                active_plugin_list.append(
-                    plugin_detector()
-                )
+            if (
+                plugin_detector is not None
+                and Options.shallDetectMissingPlugins()
+                and plugin_detector.isRelevant()
+            ):
+                active_plugin_list.append(plugin_detector())
 
     importUserPlugins()
 
