@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -25,17 +25,18 @@ from nuitka import Options
 from nuitka.plugins.PluginBase import NuitkaPluginBase
 
 known_data_files = {
-    "nose.core" : (
-        (None, "usage.txt"),
-    ),
-    "scrapy"    : (
-        (None, "VERSION"),
-    ),
-    "requests"  : (
-        ("certifi", "../certifi/cacert.pem"),
-    )
+    # Key is the package name to trigger it
+    # Value is a tuple of 2 element tuples, thus trailing commas, where
+    # the target path can be specified (None is just default, i.e. the
+    # package directory) and the filename relative to the source package
+    # directory
+    "nose.core": ((None, "usage.txt"),),
+    "scrapy": ((None, "VERSION"),),
+    "requests": (("certifi", "../certifi/cacert.pem"),),
+    "importlib_resources": ((None, "version.txt"),),
 }
 
+
 class NuitkaPluginDataFileCollector(NuitkaPluginBase):
     plugin_name = "data-files"
 
@@ -47,20 +48,14 @@ class NuitkaPluginDataFileCollector(NuitkaPluginBase):
         if module.getFullName() in known_data_files:
             for target_dir, filename in known_data_files[module.getFullName()]:
                 source_path = os.path.join(
-                    os.path.dirname(module.getCompileTimeFilename()),
-                    filename
+                    os.path.dirname(module.getCompileTimeFilename()), filename
                 )
 
                 if os.path.isfile(source_path):
                     if target_dir is None:
-                        target_dir = module.getFullName().replace('.', os.path.sep)
+                        target_dir = module.getFullName().replace(".", os.path.sep)
 
                     yield (
                         source_path,
-                        os.path.normpath(
-                            os.path.join(
-                                target_dir,
-                                filename
-                            )
-                        )
+                        os.path.normpath(os.path.join(target_dir, filename)),
                     )
