@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -36,27 +36,48 @@ from nuitka.utils.FileOperations import listDir
 # other files must appear later.  Files may be deleted if they are not
 # used.
 files = [
-    "Dialog", "TimeFuncs", "Balloon", "ButtonBox", "EntryField",
-    "Group", "LabeledWidget", "MainMenuBar", "MenuBar", "MessageBar",
-    "MessageDialog", "NoteBook", "OptionMenu", "PanedWidget", "PromptDialog",
-    "RadioSelect", "ScrolledCanvas", "ScrolledField", "ScrolledFrame",
-    "ScrolledListBox", "ScrolledText", "HistoryText", "SelectionDialog",
-    "TextDialog", "TimeCounter", "AboutDialog", "ComboBox", "ComboBoxDialog",
-    "Counter", "CounterDialog",
+    "Dialog",
+    "TimeFuncs",
+    "Balloon",
+    "ButtonBox",
+    "EntryField",
+    "Group",
+    "LabeledWidget",
+    "MainMenuBar",
+    "MenuBar",
+    "MessageBar",
+    "MessageDialog",
+    "NoteBook",
+    "OptionMenu",
+    "PanedWidget",
+    "PromptDialog",
+    "RadioSelect",
+    "ScrolledCanvas",
+    "ScrolledField",
+    "ScrolledFrame",
+    "ScrolledListBox",
+    "ScrolledText",
+    "HistoryText",
+    "SelectionDialog",
+    "TextDialog",
+    "TimeCounter",
+    "AboutDialog",
+    "ComboBox",
+    "ComboBoxDialog",
+    "Counter",
+    "CounterDialog",
 ]
 
 # Work out which version is being bundled.
 
+
 class NuitkaPluginPmw(NuitkaPluginBase):
     plugin_name = "pmw-freezer"
 
     def onModuleSourceCode(self, module_name, source_code):
         if module_name == "Pmw":
             pmw_path = self.locateModule(
-                importing      = None,
-                module_name    = "Pmw",
-                module_package = None,
-                warn           = True
+                importing=None, module_name="Pmw", module_package=None, warn=True
             )
 
             return self._packagePmw(pmw_path)
@@ -76,7 +97,7 @@ class NuitkaPluginPmw(NuitkaPluginBase):
                         return 1
             return 0
 
-        # This mimicks the scan the __init__.py does.
+        # This mimics the scan the __init__.py does.
         candidates = []
         for _fullpath, candidate in listDir(pmw_path):
             if _hasLoader(candidate):
@@ -89,7 +110,7 @@ class NuitkaPluginPmw(NuitkaPluginBase):
             sys.exit("Error, cannot find any Pmw versions.")
 
         candidate = os.path.join(pmw_path, candidates[0], "lib")
-        version = candidates[0][4:].replace('_', '.')
+        version = candidates[0][4:].replace("_", ".")
 
         return self._packagePmw2(candidate, version)
 
@@ -102,7 +123,7 @@ class NuitkaPluginPmw(NuitkaPluginBase):
             text = re.sub(r"import Pmw\>", "", text)
             text = re.sub("INITOPT = Pmw.INITOPT", "", text)
             text = re.sub(r"\<Pmw\.", "", text)
-            text = '\n' + ('#' * 70) + '\n' + "### File: " + filename + '\n' + text
+            text = "\n" + ("#" * 70) + "\n" + "### File: " + filename + "\n" + text
             return text
 
         # Code to import the Color module.
