@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -31,14 +31,14 @@ from contextlib import contextmanager
 
 from nuitka.Tracing import my_print
 from nuitka.utils.AppDirs import getAppDir, getCacheDir
-from nuitka.utils.Execution import check_output
+from nuitka.utils.Execution import check_output, withEnvironmentVarOverriden
 from nuitka.utils.FileOperations import makePath, removeDirectory
 
 from .SearchModes import (
     SearchModeBase,
     SearchModeByPattern,
     SearchModeCoverage,
-    SearchModeResume
+    SearchModeResume,
 )
 
 
@@ -46,11 +46,7 @@ def check_result(*popenargs, **kwargs):
     if "stdout" in kwargs:
         raise ValueError("stdout argument not allowed, it will be overridden.")
 
-    process = subprocess.Popen(
-        stdout = subprocess.PIPE,
-        *popenargs,
-        **kwargs
-    )
+    process = subprocess.Popen(stdout=subprocess.PIPE, *popenargs, **kwargs)
     _unused_output, _unused_err = process.communicate()
     retcode = process.poll()
 
@@ -62,31 +58,34 @@ def check_result(*popenargs, **kwargs):
 
 def goMainDir():
     # Go its own directory, to have it easy with path knowledge.
-    os.chdir(
-        os.path.dirname(
-            os.path.abspath(sys.modules[ "__main__" ].__file__)
-        )
-    )
+    os.chdir(os.path.dirname(os.path.abspath(sys.modules["__main__"].__file__)))
+
 
 _python_version = None
 _python_arch = None
 _python_executable = None
 
-def setup(needs_io_encoding = False, silent = False, go_main = True):
+
+def setup(suite="", needs_io_encoding=False, silent=False, go_main=True):
     if go_main:
         goMainDir()
 
     if "PYTHON" not in os.environ:
         os.environ["PYTHON"] = sys.executable
 
+    # Allow test code to use this to make caching specific.
+    os.environ["NUITKA_TEST_SUITE"] = suite
+
     # Allow providing 33, 27, and expand that to python2.7
-    if len(os.environ["PYTHON"]) == 2 and \
-       os.environ["PYTHON"].isdigit() and \
-       os.name != "nt":
+    if (
+        len(os.environ["PYTHON"]) == 2
+        and os.environ["PYTHON"].isdigit()
+        and os.name != "nt"
+    ):
 
         os.environ["PYTHON"] = "python%s.%s" % (
             os.environ["PYTHON"][0],
-            os.environ["PYTHON"][1]
+            os.environ["PYTHON"][1],
         )
 
     if needs_io_encoding and "PYTHONIOENCODING" not in os.environ:
@@ -103,16 +102,16 @@ print(("x86_64" if "AMD64" in sys.version else "x86") if os.name == "nt" else os
 print(sys.executable);\
 """,
         ),
-        stderr = subprocess.STDOUT
+        stderr=subprocess.STDOUT,
     )
 
-    global _python_version, _python_arch, _python_executable # singleton, pylint: disable=global-statement
+    global _python_version, _python_arch, _python_executable  # singleton, pylint: disable=global-statement
 
     _python_version = version_output.split(b"\n")[0].strip()
     _python_arch = version_output.split(b"\n")[1].strip()
     _python_executable = version_output.split(b"\n")[2].strip()
 
-    if sys.version.startswith('3'):
+    if sys.version.startswith("3"):
         _python_arch = _python_arch.decode("utf-8")
         _python_version = _python_version.decode("utf-8")
         _python_executable = _python_executable.decode("utf-8")
@@ -126,11 +125,7 @@ print(sys.executable);\
 
     if "COVERAGE_FILE" not in os.environ:
         os.environ["COVERAGE_FILE"] = os.path.join(
-            os.path.dirname(__file__),
-            "..",
-            "..",
-            "..",
-            ".coverage"
+            os.path.dirname(__file__), "..", "..", "..", ".coverage"
         )
 
     return _python_version
@@ -138,6 +133,7 @@ print(sys.executable);\
 
 tmp_dir = None
 
+
 def getTempDir():
     # Create a temporary directory to work in, automatically remove it in case
     # it is empty in the end.
@@ -145,40 +141,29 @@ def getTempDir():
 
     if tmp_dir is None:
         tmp_dir = tempfile.mkdtemp(
-            prefix = os.path.basename(
-                os.path.dirname(
-                    os.path.abspath(sys.modules[ "__main__" ].__file__)
-                )
-            ) + '-',
-            dir    = tempfile.gettempdir() if
-                         not os.path.exists("/var/tmp") else
-                    "/var/tmp"
+            prefix=os.path.basename(
+                os.path.dirname(os.path.abspath(sys.modules["__main__"].__file__))
+            )
+            + "-",
+            dir=tempfile.gettempdir() if not os.path.exists("/var/tmp") else "/var/tmp",
         )
 
         def removeTempDir():
-            removeDirectory(
-                path          = tmp_dir,
-                ignore_errors = True
-            )
+            removeDirectory(path=tmp_dir, ignore_errors=True)
 
         atexit.register(removeTempDir)
 
     return tmp_dir
 
 
-def convertUsing2to3(path, force = False):
-    command = [
-        os.environ["PYTHON"],
-        "-m",
-        "py_compile",
-        path
-    ]
+def convertUsing2to3(path, force=False):
+    command = [os.environ["PYTHON"], "-m", "py_compile", path]
 
     if not force:
         with open(path) as source_file:
             if "xrange" not in source_file.read():
-                with open(os.devnull, 'w') as stderr:
-                    if check_result(command, stderr = stderr):
+                with open(os.devnull, "w") as stderr:
+                    if check_result(command, stderr=stderr):
                         return path, False
 
     filename = os.path.basename(path)
@@ -192,46 +177,38 @@ def convertUsing2to3(path, force = False):
         pass
 
     # For Python2.6 and 3.2 the -m lib2to3 was not yet supported.
-    use_binary = sys.version_info[:2] in ((2,6), (3,2))
+    use_binary = sys.version_info[:2] in ((2, 6), (3, 2))
 
     if use_binary:
         # On Windows, we cannot rely on 2to3 to be in the path.
         if os.name == "nt":
             command = [
                 sys.executable,
-                os.path.join(
-                    os.path.dirname(sys.executable),
-                    "Tools/Scripts/2to3.py"
-                )
+                os.path.join(os.path.dirname(sys.executable), "Tools/Scripts/2to3.py"),
             ]
         else:
-            command = [
-                "2to3"
-            ]
+            command = ["2to3"]
     else:
-        command = [
-            sys.executable,
-            "-m",
-            "lib2to3",
-        ]
+        command = [sys.executable, "-m", "lib2to3"]
 
-    command += [
-        "-w",
-        "-n",
-        "--no-diffs",
-        new_path
-    ]
+    command += ["-w", "-n", "--no-diffs", new_path]
 
-    with open(os.devnull, 'w') as devnull:
-        check_output(
-            command,
-            stderr = devnull
-        )
+    with open(os.devnull, "w") as devnull:
+        try:
+            check_output(command, stderr=devnull)
+
+        except subprocess.CalledProcessError:
+            if os.name == "nt":
+                raise
+
+            command[0:3] = ["2to3"]
+
+            check_output(command, stderr=devnull)
 
     with open(new_path) as result_file:
         data = result_file.read()
 
-    with open(new_path, 'w') as result_file:
+    with open(new_path, "w") as result_file:
         result_file.write("__file__ = %r\n" % os.path.abspath(path))
         result_file.write(data)
 
@@ -266,7 +243,7 @@ def decideFilenameVersionSkip(filename):
     if filename.endswith("27.py") and _python_version.startswith("2.6"):
         return False
 
-    if filename.endswith("_2.py") and _python_version.startswith('3'):
+    if filename.endswith("_2.py") and _python_version.startswith("3"):
         return False
 
     # Skip tests that require Python 3.2 at least.
@@ -296,7 +273,7 @@ def _removeCPythonTestSuiteDir():
     # Cleanup, some tests apparently forget that.
     try:
         if os.path.isdir("@test"):
-            removeDirectory("@test", ignore_errors = False)
+            removeDirectory("@test", ignore_errors=False)
         elif os.path.isfile("@test"):
             os.unlink("@test")
     except OSError:
@@ -310,6 +287,7 @@ def _removeCPythonTestSuiteDir():
         if os.path.exists("@test"):
             raise
 
+
 def compareWithCPython(dirname, filename, extra_flags, search_mode, needs_2to3):
     """ Call the comparison tool. For a given directory filename.
 
@@ -333,7 +311,7 @@ def compareWithCPython(dirname, filename, extra_flags, search_mode, needs_2to3):
         sys.executable,
         os.path.join("..", "..", "bin", "compare_with_cpython"),
         path,
-        "silent"
+        "silent",
     ]
 
     if extra_flags is not None:
@@ -345,18 +323,14 @@ def compareWithCPython(dirname, filename, extra_flags, search_mode, needs_2to3):
     _removeCPythonTestSuiteDir()
 
     try:
-        result = subprocess.call(
-            command
-        )
+        result = subprocess.call(command)
     except KeyboardInterrupt:
         result = 2
 
     # Cleanup before and after test stage directory.
     _removeCPythonTestSuiteDir()
 
-    if result != 0 and \
-       result != 2 and \
-       search_mode.abortOnFinding(dirname, filename):
+    if result != 0 and result != 2 and search_mode.abortOnFinding(dirname, filename):
         my_print("Error exit!", result)
         sys.exit(result)
 
@@ -374,36 +348,23 @@ def checkCompilesNotWithCPython(dirname, filename, search_mode):
     else:
         path = os.path.join(dirname, filename)
 
-    command = [
-        _python_executable,
-        "-mcompileall",
-        path
-    ]
+    command = [_python_executable, "-mcompileall", path]
 
     try:
-        result = subprocess.call(
-            command
-        )
+        result = subprocess.call(command)
     except KeyboardInterrupt:
         result = 2
 
-    if result != 1 and \
-       result != 2 and \
-       search_mode.abortOnFinding(dirname, filename):
+    if result != 1 and result != 2 and search_mode.abortOnFinding(dirname, filename):
         my_print("Error exit!", result)
         sys.exit(result)
 
 
 def checkSucceedsWithCPython(filename):
-    command = [
-        _python_executable,
-        filename
-    ]
+    command = [_python_executable, filename]
 
     result = subprocess.call(
-        command,
-        stdout = open(os.devnull,'w'),
-        stderr = subprocess.STDOUT
+        command, stdout=open(os.devnull, "w"), stderr=subprocess.STDOUT
     )
 
     return result == 0
@@ -426,8 +387,7 @@ def hasDebugPython():
     # For other Python, if it's the one also executing the runner, which is
     # very probably the case, we check that. We don't check the provided
     # binary here, this could be done as well.
-    if sys.executable == os.environ["PYTHON"] and \
-       hasattr(sys, "gettotalrefcount"):
+    if sys.executable == os.environ["PYTHON"] and hasattr(sys, "gettotalrefcount"):
         return True
 
     # Otherwise no.
@@ -450,19 +410,14 @@ def getDependsExePath():
 
     nuitka_app_dir = getAppDir()
 
-    depends_dir = os.path.join(
-        nuitka_app_dir,
-        _python_arch,
-    )
-    depends_exe = os.path.join(
-        depends_dir,
-        "depends.exe"
-    )
+    depends_dir = os.path.join(nuitka_app_dir, _python_arch)
+    depends_exe = os.path.join(depends_dir, "depends.exe")
 
     assert os.path.exists(depends_exe), depends_exe
 
     return depends_exe
 
+
 def isExecutableCommand(command):
     path = os.environ["PATH"]
 
@@ -479,7 +434,7 @@ def isExecutableCommand(command):
     return False
 
 
-def getRuntimeTraceOfLoadedFiles(path, trace_error = True):
+def getRuntimeTraceOfLoadedFiles(path, trace_error=True):
     """ Returns the files loaded when executing a binary. """
 
     # This will make a crazy amount of work, pylint: disable=too-many-branches,too-many-statements
@@ -487,8 +442,7 @@ def getRuntimeTraceOfLoadedFiles(path, trace_error = True):
     result = []
 
     if os.name == "posix":
-        if sys.platform == "darwin" or \
-           sys.platform.startswith("freebsd"):
+        if sys.platform == "darwin" or sys.platform.startswith("freebsd"):
             if not isExecutableCommand("dtruss"):
                 sys.exit(
                     """\
@@ -501,13 +455,7 @@ Error, needs 'dtruss' on your system to scan used libraries."""
 Error, needs 'sudo' on your system to scan used libraries."""
                 )
 
-            args = (
-                "sudo",
-                "dtruss",
-                "-t",
-                "open",
-                path
-            )
+            args = ("sudo", "dtruss", "-t", "open", path)
         else:
             if not isExecutableCommand("strace"):
                 sys.exit(
@@ -517,90 +465,96 @@ Error, needs 'strace' on your system to scan used libraries."""
 
             args = (
                 "strace",
-                "-e", "file",
-                "-s4096", # Some paths are truncated otherwise.
-                path
+                "-e",
+                "file",
+                "-s4096",  # Some paths are truncated otherwise.
+                path,
             )
 
-        process = subprocess.Popen(
-            args   = args,
-            stdout = subprocess.PIPE,
-            stderr = subprocess.PIPE
-        )
+        # Ensure executable is not polluted with third party stuff,
+        # tests may fail otherwise due to unexpected libs being loaded
+        with withEnvironmentVarOverriden("LD_PRELOAD", None):
+            process = subprocess.Popen(
+                args=args, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+            )
 
-        _stdout_strace, stderr_strace = process.communicate()
-        exit_strace = process.returncode
+            _stdout_strace, stderr_strace = process.communicate()
+            exit_strace = process.returncode
 
-        if exit_strace != 0:
-            if str is not bytes:
-                stderr_strace = stderr_strace.decode("utf8")
-
-            my_print(stderr_strace, file = sys.stderr)
-            sys.exit("Failed to run strace.")
-
-        open(path+".strace","wb").write(stderr_strace)
-
-        for line in stderr_strace.split(b"\n"):
-            if process.returncode != 0 and trace_error:
-                my_print(line)
-
-            if not line:
-                continue
-
-            # Don't consider files not found. The "site" module checks lots
-            # of things.
-            if b"ENOENT" in line:
-                continue
-
-            if line.startswith(b"stat(") and b"S_IFDIR" in line:
-                continue
-
-            # Allow stats on the python binary, and stuff pointing to the
-            # standard library, just not uses of it. It will search there
-            # for stuff.
-            if line.startswith(b"lstat(") or \
-               line.startswith(b"stat(") or \
-               line.startswith(b"readlink("):
-                filename = line[line.find(b"(")+2:line.find(b", ")-1]
-
-                # At least Python3.7 considers the default Python3 path.
-                if filename == b"/usr/bin/python3":
-                    continue
-
-                if filename in (b"/usr/bin/python3." + version for version in (b"5", b"6", b"7")):
-                    continue
-
-                binary_path = _python_executable
+            if exit_strace != 0:
                 if str is not bytes:
-                    binary_path = binary_path.encode("utf-8")
+                    stderr_strace = stderr_strace.decode("utf8")
 
-                found = False
-                while binary_path:
-                    if filename == binary_path:
-                        found = True
-                        break
+                my_print(stderr_strace, file=sys.stderr)
+                sys.exit("Failed to run strace.")
 
-                    if binary_path == os.path.dirname(binary_path):
-                        break
+            open(path + ".strace", "wb").write(stderr_strace)
 
-                    binary_path = os.path.dirname(binary_path)
+            for line in stderr_strace.split(b"\n"):
+                if process.returncode != 0 and trace_error:
+                    my_print(line)
 
-                    if filename == os.path.join(binary_path, b"python" + _python_version[:3].encode("utf8")):
-                        found = True
+                if not line:
+                    continue
+
+                # Don't consider files not found. The "site" module checks lots
+                # of things.
+                if b"ENOENT" in line:
+                    continue
+
+                if line.startswith(b"stat(") and b"S_IFDIR" in line:
+                    continue
+
+                # Allow stats on the python binary, and stuff pointing to the
+                # standard library, just not uses of it. It will search there
+                # for stuff.
+                if (
+                    line.startswith(b"lstat(")
+                    or line.startswith(b"stat(")
+                    or line.startswith(b"readlink(")
+                ):
+                    filename = line[line.find(b"(") + 2 : line.find(b", ") - 1]
+
+                    # At least Python3.7 considers the default Python3 path.
+                    if filename == b"/usr/bin/python3":
                         continue
 
+                    if filename in (
+                        b"/usr/bin/python3." + version for version in (b"5", b"6", b"7")
+                    ):
+                        continue
 
-                if found:
-                    continue
+                    binary_path = _python_executable
+                    if str is not bytes:
+                        binary_path = binary_path.encode("utf-8")
 
-            result.extend(
-                os.path.abspath(match)
-                for match in
-                re.findall(b'"(.*?)(?:\\\\0)?"', line)
-            )
+                    found = False
+                    while binary_path:
+                        if filename == binary_path:
+                            found = True
+                            break
 
-        if sys.version.startswith('3'):
-            result = [s.decode("utf-8") for s in result]
+                        if binary_path == os.path.dirname(binary_path):
+                            break
+
+                        binary_path = os.path.dirname(binary_path)
+
+                        if filename == os.path.join(
+                            binary_path, b"python" + _python_version[:3].encode("utf8")
+                        ):
+                            found = True
+                            continue
+
+                    if found:
+                        continue
+
+                result.extend(
+                    os.path.abspath(match)
+                    for match in re.findall(b'"(.*?)(?:\\\\0)?"', line)
+                )
+
+            if sys.version.startswith("3"):
+                result = [s.decode("utf-8") for s in result]
     elif os.name == "nt":
         subprocess.call(
             (
@@ -612,7 +566,7 @@ Error, needs 'strace' on your system to scan used libraries."""
                 "-ps1",
                 "-pp0",
                 "-pl1",
-                path
+                path,
             )
         )
 
@@ -628,19 +582,20 @@ Error, needs 'strace' on your system to scan used libraries."""
             if "| Module List |" in line:
                 break
 
-            if ']' not in line:
+            if "]" not in line:
                 continue
 
             # Skip missing DLLs, apparently not needed anyway.
-            if '?' in line[:line.find(']')]:
+            if "?" in line[: line.find("]")]:
                 continue
 
-            dll_filename = line[line.find(']')+2:-1]
+            dll_filename = line[line.find("]") + 2 : -1]
             assert os.path.isfile(dll_filename), dll_filename
 
             # The executable itself is of course exempted.
-            if os.path.normcase(dll_filename) == \
-                os.path.normcase(os.path.abspath(path)):
+            if os.path.normcase(dll_filename) == os.path.normcase(
+                os.path.abspath(path)
+            ):
                 continue
 
             dll_filename = os.path.normcase(dll_filename)
@@ -721,20 +676,40 @@ def checkRuntimeLoadedFilesForOutsideAccesses(loaded_filenames, white_list):
             continue
 
         # System C libraries are to be expected.
-        if loaded_basename.startswith((
-            "libc.so.",
-            "libpthread.so.",
-            "libdl.so.",
-            "libm.so.",
-        )):
+        if loaded_basename.startswith(
+            (
+                "ld-linux-x86-64.so",
+                "libc.so.",
+                "libpthread.so.",
+                "libm.so.",
+                "libdl.so.",
+                "libBrokenLocale.so.",
+                "libSegFault.so",
+                "libanl.so.",
+                "libcidn.so.",
+                "libcrypt.so.",
+                "libmemusage.so",
+                "libmvec.so.",
+                "libnsl.so.",
+                "libnss_compat.so.",
+                "libnss_db.so.",
+                "libnss_dns.so.",
+                "libnss_files.so.",
+                "libnss_hesiod.so.",
+                "libnss_nis.so.",
+                "libnss_nisplus.so.",
+                "libpcprofile.so",
+                "libresolv.so.",
+                "librt.so.",
+                "libthread_db-1.0.so",
+                "libthread_db.so.",
+                "libutil.so.",
+            )
+        ):
             continue
 
         # Taking these from system is harmless and desirable
-        if loaded_basename.startswith((
-            "libz.so",
-            "libutil.so",
-            "libgcc_s.so",
-        )):
+        if loaded_basename.startswith(("libz.so", "libgcc_s.so")):
             continue
 
         # TODO: Unclear, loading gconv from filesystem of installed system
@@ -757,13 +732,9 @@ def checkRuntimeLoadedFilesForOutsideAccesses(loaded_filenames, white_list):
 
 def hasModule(module_name):
     result = subprocess.call(
-        (
-            os.environ["PYTHON"],
-            "-c"
-            "import %s" % module_name
-        ),
-        stdout = open(os.devnull,'w'),
-        stderr = subprocess.STDOUT
+        (os.environ["PYTHON"], "-c" "import %s" % module_name),
+        stdout=open(os.devnull, "w"),
+        stderr=subprocess.STDOUT,
     )
 
     return result == 0
@@ -772,6 +743,7 @@ def hasModule(module_name):
 m1 = {}
 m2 = {}
 
+
 def snapObjRefCntMap(before):
     import gc
 
@@ -787,13 +759,13 @@ def snapObjRefCntMap(before):
         if x is m2:
             continue
 
-        m[ str(x) ] = sys.getrefcount(x)
+        m[str(x)] = sys.getrefcount(x)
 
 
-def checkReferenceCount(checked_function, max_rounds = 10):
+def checkReferenceCount(checked_function, max_rounds=10):
     assert sys.exc_info() == (None, None, None), sys.exc_info()
 
-    print(checked_function.__name__ + ": ", end = "")
+    print(checked_function.__name__ + ": ", end="")
     sys.stdout.flush()
 
     ref_count1 = 17
@@ -839,10 +811,10 @@ def checkReferenceCount(checked_function, max_rounds = 10):
 
             for key in m1:
                 if key not in m2:
-                    print('*' * 80)
+                    print("*" * 80)
                     print("extra", key)
                 elif m1[key] != m2[key]:
-                    print('*' * 80)
+                    print("*" * 80)
                     print(m1[key], "->", m2[key], key)
                 else:
                     pass
@@ -856,32 +828,31 @@ def checkReferenceCount(checked_function, max_rounds = 10):
     return result
 
 
-
 def createSearchMode():
     search_mode = len(sys.argv) > 1 and sys.argv[1] == "search"
     resume_mode = len(sys.argv) > 1 and sys.argv[1] == "resume"
     start_at = sys.argv[2] if len(sys.argv) > 2 else None
     coverage_mode = len(sys.argv) > 1 and sys.argv[1] == "coverage"
 
-
     if coverage_mode:
 
         return SearchModeCoverage()
     elif resume_mode:
-        return SearchModeResume(
-            sys.modules["__main__"].__file__
-        )
+        return SearchModeResume(sys.modules["__main__"].__file__)
     elif search_mode and start_at:
-        start_at = start_at.replace('/', os.path.sep)
+        start_at = start_at.replace("/", os.path.sep)
         return SearchModeByPattern(start_at)
     else:
+
         class SearchModeImmediate(SearchModeBase):
             def abortOnFinding(self, dirname, filename):
-                return search_mode and \
-                       SearchModeBase.abortOnFinding(self, dirname, filename)
+                return search_mode and SearchModeBase.abortOnFinding(
+                    self, dirname, filename
+                )
 
         return SearchModeImmediate()
 
+
 def reportSkip(reason, dirname, filename):
     case = os.path.join(dirname, filename)
     case = os.path.normpath(case)
@@ -891,15 +862,14 @@ def reportSkip(reason, dirname, filename):
 
 def executeReferenceChecked(prefix, names, tests_skipped, tests_stderr):
     import gc
+
     gc.disable()
 
     extract_number = lambda name: int(name.replace(prefix, ""))
 
     # Find the function names.
     matching_names = tuple(
-        name
-        for name in names
-        if name.startswith(prefix) and name[-1].isdigit()
+        name for name in names if name.startswith(prefix) and name[-1].isdigit()
     )
 
     old_stderr = sys.stderr
@@ -907,7 +877,7 @@ def executeReferenceChecked(prefix, names, tests_skipped, tests_stderr):
     # Everything passed
     result = True
 
-    for name in sorted(matching_names, key = extract_number):
+    for name in sorted(matching_names, key=extract_number):
         number = extract_number(name)
 
         # print(tests_skipped)
@@ -919,7 +889,7 @@ def executeReferenceChecked(prefix, names, tests_skipped, tests_stderr):
         try:
             if number in tests_stderr:
                 sys.stderr = open(os.devnull, "wb")
-        except OSError: # Windows
+        except OSError:  # Windows
             if not checkReferenceCount(names[name]):
                 result = False
         else:
@@ -938,10 +908,12 @@ def executeReferenceChecked(prefix, names, tests_skipped, tests_stderr):
 def checkDebugPython():
     if not hasattr(sys, "gettotalrefcount"):
         my_print("Warning, using non-debug Python makes this test ineffective.")
-        sys.gettotalrefcount = lambda : 0
-    elif sys.version_info >= (3,7,0) and sys.version_info < (3,7,1):
-        my_print("Warning, bug of CPython 3.7.0 breaks reference counting and makes this test ineffective.")
-        sys.gettotalrefcount = lambda : 0
+        sys.gettotalrefcount = lambda: 0
+    elif sys.version_info >= (3, 7, 0) and sys.version_info < (3, 7, 1):
+        my_print(
+            "Warning, bug of CPython 3.7.0/1 breaks reference counting and makes this test ineffective."
+        )
+        sys.gettotalrefcount = lambda: 0
 
 
 def addToPythonPath(python_path):
@@ -962,9 +934,7 @@ def withPythonPathChange(python_path):
             python_path = python_path.split(os.pathsep)
 
         python_path = [
-            os.path.normpath(os.path.abspath(element))
-            for element in
-            python_path
+            os.path.normpath(os.path.abspath(element)) for element in python_path
         ]
 
         python_path = os.pathsep.join(python_path)
@@ -976,12 +946,12 @@ def withPythonPathChange(python_path):
             old_path = None
             os.environ["PYTHONPATH"] = python_path
 
-#     print(
-#         "Effective PYTHONPATH in %s is %r" % (
-#             sys.modules["__main__"],
-#             os.environ.get("PYTHONPATH", "")
-#         )
-#     )
+    #     print(
+    #         "Effective PYTHONPATH in %s is %r" % (
+    #             sys.modules["__main__"],
+    #             os.environ.get("PYTHONPATH", "")
+    #         )
+    #     )
 
     yield
 
@@ -1003,35 +973,36 @@ def withExtendedExtraOptions(*args):
         if value is None:
             value = arg
         else:
-            value += ' ' + arg
+            value += " " + arg
 
-    os.environ[ "NUITKA_EXTRA_OPTIONS" ] = value
+    os.environ["NUITKA_EXTRA_OPTIONS"] = value
 
     yield
 
     if old_value is None:
-        del os.environ[ "NUITKA_EXTRA_OPTIONS" ]
+        del os.environ["NUITKA_EXTRA_OPTIONS"]
     else:
-        os.environ[ "NUITKA_EXTRA_OPTIONS" ] = old_value
+        os.environ["NUITKA_EXTRA_OPTIONS"] = old_value
 
 
 def indentedCode(codes, count):
     """ Indent code, used for generating test codes.
 
     """
-    return '\n'.join( ' ' * count + line if line else "" for line in codes )
+    return "\n".join(" " * count + line if line else "" for line in codes)
 
 
-def convertToPython(doctests, line_filter = None):
+def convertToPython(doctests, line_filter=None):
     """ Convert give doctest string to static Python code.
 
     """
     # This is convoluted, but it just needs to work, pylint: disable=too-many-branches
 
     import doctest
+
     code = doctest.script_from_examples(doctests)
 
-    if code.endswith('\n'):
+    if code.endswith("\n"):
         code += "#\n"
     else:
         assert False
@@ -1048,15 +1019,25 @@ def convertToPython(doctests, line_filter = None):
         if node.body[0].__class__.__name__ == "Expr":
             count = 0
 
-            while evaluated.startswith(' ' * count):
+            while evaluated.startswith(" " * count):
                 count += 1
 
             if sys.version_info < (3,):
-                modified = (count-1) * ' ' + "print " + evaluated
-                return (count-1) * ' ' + ("print 'Line %d'" % line_number) + '\n' + modified
+                modified = (count - 1) * " " + "print " + evaluated
+                return (
+                    (count - 1) * " "
+                    + ("print 'Line %d'" % line_number)
+                    + "\n"
+                    + modified
+                )
             else:
-                modified = (count-1) * ' ' + "print(" + evaluated + "\n)\n"
-                return (count-1) * ' ' + ("print('Line %d'" % line_number) + ")\n" + modified
+                modified = (count - 1) * " " + "print(" + evaluated + "\n)\n"
+                return (
+                    (count - 1) * " "
+                    + ("print('Line %d'" % line_number)
+                    + ")\n"
+                    + modified
+                )
         else:
             return evaluated
 
@@ -1067,14 +1048,22 @@ try:
 %(evaluated)s
 except Exception as __e:
     print "Occurred", type(__e), __e
-""" % { "evaluated" : indentedCode(getPrintPrefixed(evaluated, line_number).split('\n'), 4) }
+""" % {
+                "evaluated": indentedCode(
+                    getPrintPrefixed(evaluated, line_number).split("\n"), 4
+                )
+            }
         else:
             return """
 try:
 %(evaluated)s
 except Exception as __e:
     print("Occurred", type(__e), __e)
-""" % { "evaluated" : indentedCode(getPrintPrefixed(evaluated, line_number).split('\n'), 4) }
+""" % {
+                "evaluated": indentedCode(
+                    getPrintPrefixed(evaluated, line_number).split("\n"), 4
+                )
+            }
 
     def isOpener(evaluated):
         evaluated = evaluated.lstrip()
@@ -1083,26 +1072,33 @@ except Exception as __e:
             return False
 
         return evaluated.split()[0] in (
-            "def", "class", "for", "while", "try:", "except", "except:",
-            "finally:", "else:"
+            "def",
+            "class",
+            "for",
+            "while",
+            "try:",
+            "except",
+            "except:",
+            "finally:",
+            "else:",
         )
 
     chunk = None
-    for line_number, line in enumerate(code.split('\n')):
+    for line_number, line in enumerate(code.split("\n")):
         # print "->", inside, line
 
         if line_filter is not None and line_filter(line):
             continue
 
         if inside and line and line[0].isalnum() and not isOpener(line):
-            output.append(getTried('\n'.join(chunk), line_number))  # @UndefinedVariable
+            output.append(getTried("\n".join(chunk), line_number))  # @UndefinedVariable
 
             chunk = []
             inside = False
 
-        if inside and not (line.startswith('#') and line.find("SyntaxError:") != -1):
+        if inside and not (line.startswith("#") and line.find("SyntaxError:") != -1):
             chunk.append(line)
-        elif line.startswith('#'):
+        elif line.startswith("#"):
             if line.find("SyntaxError:") != -1:
                 # print "Syntax error detected"
 
@@ -1121,29 +1117,21 @@ except Exception as __e:
         else:
             output.append(getTried(line, line_number))
 
-    return '\n'.join(output).rstrip() + '\n'
+    return "\n".join(output).rstrip() + "\n"
 
 
 def compileLibraryPath(search_mode, path, stage_dir, decide, action):
     my_print("Checking standard library path:", path)
 
     for root, dirnames, filenames in os.walk(path):
-        dirnames_to_remove = [
-            dirname
-            for dirname in dirnames
-            if '-' in dirname
-        ]
+        dirnames_to_remove = [dirname for dirname in dirnames if "-" in dirname]
 
         for dirname in dirnames_to_remove:
             dirnames.remove(dirname)
 
         dirnames.sort()
 
-        filenames = [
-            filename
-            for filename in filenames
-            if decide(root, filename)
-        ]
+        filenames = [filename for filename in filenames if decide(root, filename)]
 
         for filename in sorted(filenames):
             if not search_mode.consider(root, filename):
@@ -1151,7 +1139,7 @@ def compileLibraryPath(search_mode, path, stage_dir, decide, action):
 
             full_path = os.path.join(root, filename)
 
-            my_print(full_path, ':', end = ' ')
+            my_print(full_path, ":", end=" ")
             sys.stdout.flush()
 
             action(stage_dir, path, full_path)
@@ -1164,12 +1152,7 @@ def compileLibraryTest(search_mode, stage_dir, decide, action):
     my_dirname = os.path.join(os.path.dirname(__file__), "../../..")
     my_dirname = os.path.normpath(my_dirname)
 
-    paths = [
-        path
-        for path in
-        sys.path
-        if not path.startswith(my_dirname)
-    ]
+    paths = [path for path in sys.path if not path.startswith(my_dirname)]
 
     my_print("Using standard library paths:")
     for path in paths:
@@ -1178,13 +1161,15 @@ def compileLibraryTest(search_mode, stage_dir, decide, action):
     for path in paths:
         print("Checking path:", path)
         compileLibraryPath(
-            search_mode = search_mode,
-            path        = path,
-            stage_dir   = stage_dir,
-            decide      = decide,
-            action      = action
+            search_mode=search_mode,
+            path=path,
+            stage_dir=stage_dir,
+            decide=decide,
+            action=action,
         )
 
+    search_mode.finish()
+
 
 def run_async(coro):
     """ Execute a coroutine until it's done. """
@@ -1238,12 +1223,16 @@ def getTestingCacheDir():
 def getTestingCPythonOutputsCacheDir():
     cache_dir = getCacheDir()
 
-    result = os.path.join(cache_dir, "cpython_outputs")
+    result = os.path.join(
+        cache_dir, "cpython_outputs", os.environ.get("NUITKA_TEST_SUITE", "")
+    )
+
     makePath(result)
     return result
 
+
 @contextmanager
-def withDirectoryChange(path, allow_none = False):
+def withDirectoryChange(path, allow_none=False):
     if path is not None or not allow_none:
         old_cwd = os.getcwd()
         os.chdir(path)
@@ -1259,6 +1248,7 @@ def someGenerator():
     yield 2
     yield 3
 
+
 def someGeneratorRaising():
     yield 1
     raise TypeError(2)
