@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -35,10 +35,11 @@ import time
 from nuitka.tools.testing.Common import (
     addToPythonPath,
     getTestingCPythonOutputsCacheDir,
-    withPythonPathChange
+    withPythonPathChange,
 )
 from nuitka.tools.testing.OutputComparison import compareOutput
 from nuitka.Tracing import my_print
+from nuitka.utils.Timing import StopWatch
 
 
 def displayOutput(stdout, stderr):
@@ -46,22 +47,27 @@ def displayOutput(stdout, stderr):
         stdout = stdout.decode("utf-8" if os.name != "nt" else "cp850")
         stderr = stderr.decode("utf-8" if os.name != "nt" else "cp850")
 
-    my_print(stdout, end = ' ')
+    my_print(stdout, end=" ")
     if stderr:
         my_print(stderr)
 
 
 def checkNoPermissionError(output):
     # Forms of permission errors.
-    for candidate in (b"Permission denied:",
-                      b"PermissionError:",
-                      b"DBPermissionsError:"):
+    for candidate in (
+        b"Permission denied:",
+        b"PermissionError:",
+        b"DBPermissionsError:",
+    ):
         if candidate in output:
             return False
 
     # These are localized it seems.
-    if re.search(b"(WindowsError|FileNotFoundError|FileExistsError|WinError 145):"
-                 b".*(@test|totest|xx|Error 145)", output):
+    if re.search(
+        b"(WindowsError|FileNotFoundError|FileExistsError|WinError 145):"
+        b".*(@test|totest|xx|Error 145)",
+        output,
+    ):
         return False
 
     # Give those a retry as well.
@@ -71,61 +77,74 @@ def checkNoPermissionError(output):
     return True
 
 
+def _getCPythonResults(cpython_cmd):
+    stop_watch = StopWatch()
+
+    # Try a coupile of times for permission denied, on Windows it can
+    # be transient.
+    for _i in range(5):
+        stop_watch.start()
+
+        with withPythonPathChange(os.getcwd()):
+            process = subprocess.Popen(
+                args=cpython_cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+            )
+
+        stdout_cpython, stderr_cpython = process.communicate()
+        exit_cpython = process.returncode
+
+        stop_watch.stop()
+
+        if checkNoPermissionError(stdout_cpython) and checkNoPermissionError(
+            stderr_cpython
+        ):
+            break
+
+        my_print("Retrying CPython due to permission problems after delay.")
+        time.sleep(2)
+
+    cpython_time = stop_watch.delta()
+
+    return cpython_time, stdout_cpython, stderr_cpython, exit_cpython
+
+
 def getCPythonResults(cpython_cmd, cpython_cached):
     cached = False
     if cpython_cached:
         # TODO: Hashing stuff and creating cache filename is duplicate code
         # and should be shared.
-
         hash_input = " -- ".join(cpython_cmd)
         if str is not bytes:
             hash_input = hash_input.encode("utf8")
 
         command_hash = hashlib.md5(hash_input)
 
+        for element in cpython_cmd:
+            if os.path.exists(element):
+                with open(element, "rb") as element_file:
+                    command_hash.update(element_file.read())
+
         cache_filename = os.path.join(
-            getTestingCPythonOutputsCacheDir(),
-            command_hash.hexdigest()
+            getTestingCPythonOutputsCacheDir(), command_hash.hexdigest()
         )
 
         if os.path.exists(cache_filename):
             with open(cache_filename, "rb") as cache_file:
-                cpython_time, stdout_cpython, stderr_cpython, exit_cpython = \
-                  pickle.load(cache_file)
+                cpython_time, stdout_cpython, stderr_cpython, exit_cpython = pickle.load(
+                    cache_file
+                )
                 cached = True
 
     if not cached:
-        start_time = time.time()
-
-        # Try a coupile of times for permission denied, on Windows it can
-        # be transient.
-        for _i in range(5):
-            with withPythonPathChange(os.getcwd()):
-                process = subprocess.Popen(
-                    args   = cpython_cmd,
-                    stdout = subprocess.PIPE,
-                    stderr = subprocess.PIPE
-                )
-
-            stdout_cpython, stderr_cpython = process.communicate()
-            exit_cpython = process.returncode
-
-            if checkNoPermissionError(stdout_cpython) and \
-               checkNoPermissionError(stderr_cpython):
-                break
-
-            my_print("Retrying CPython due to permission problems after delay.")
-            time.sleep(2)
-
-            start_time = time.time()
-
-        cpython_time = time.time() - start_time
+        cpython_time, stdout_cpython, stderr_cpython, exit_cpython = _getCPythonResults(
+            cpython_cmd
+        )
 
         if cpython_cached:
             with open(cache_filename, "wb") as cache_file:
                 pickle.dump(
                     (cpython_time, stdout_cpython, stderr_cpython, exit_cpython),
-                    cache_file
+                    cache_file,
                 )
 
     return cpython_time, stdout_cpython, stderr_cpython, exit_cpython
@@ -136,7 +155,7 @@ def main():
     from nuitka.utils.Execution import check_output
 
     filename = sys.argv[1]
-    args     = sys.argv[2:]
+    args = sys.argv[2:]
 
     def hasArg(arg):
         if arg in args:
@@ -148,61 +167,64 @@ def main():
     # For output keep it
     arguments = list(args)
 
-    silent_mode        = hasArg("silent")
-    ignore_stderr      = hasArg("ignore_stderr")
-    ignore_warnings    = hasArg("ignore_warnings")
-    ignore_infos       = hasArg("ignore_infos")
-    expect_success     = hasArg("expect_success")
-    expect_failure     = hasArg("expect_failure")
-    python_debug       = hasArg("python_debug")
-    module_mode        = hasArg("module_mode")
+    silent_mode = hasArg("silent")
+    ignore_stderr = hasArg("ignore_stderr")
+    ignore_warnings = hasArg("ignore_warnings")
+    ignore_infos = hasArg("ignore_infos")
+    expect_success = hasArg("expect_success")
+    expect_failure = hasArg("expect_failure")
+    python_debug = hasArg("python_debug")
+    module_mode = hasArg("module_mode")
     two_step_execution = hasArg("two_step_execution")
     binary_python_path = hasArg("binary_python_path")
-    keep_python_path   = hasArg("keep_python_path")
-    trace_command      = hasArg("trace_command") or os.environ.get("NUITKA_TRACE_COMMANDS", '0') != '0'
-    remove_output      = hasArg("remove_output")
-    standalone_mode    = hasArg("standalone")
-    no_site            = hasArg("no_site")
-    recurse_none       = hasArg("recurse_none")
-    recurse_all        = hasArg("recurse_all")
-    timing             = hasArg("timing")
-    coverage_mode      = hasArg("coverage")
-    original_file      = hasArg("original_file")
-    no_warnings        = not hasArg("warnings")
-    full_compat        = not hasArg("improved")
-    cpython_cached     = hasArg("cpython_cache")
-    syntax_errors      = hasArg("syntax_errors")
+    keep_python_path = hasArg("keep_python_path")
+    trace_command = (
+        hasArg("trace_command") or os.environ.get("NUITKA_TRACE_COMMANDS", "0") != "0"
+    )
+    remove_output = hasArg("remove_output")
+    standalone_mode = hasArg("standalone")
+    no_site = hasArg("no_site")
+    recurse_none = hasArg("recurse_none")
+    recurse_all = hasArg("recurse_all")
+    timing = hasArg("timing")
+    coverage_mode = hasArg("coverage")
+    original_file = hasArg("original_file")
+    runtime_file = hasArg("runtime_file")
+    no_warnings = not hasArg("warnings")
+    full_compat = not hasArg("improved")
+    cpython_cached = hasArg("cpython_cache")
+    syntax_errors = hasArg("syntax_errors")
 
     plugins_enabled = []
 
     for count, arg in reversed(tuple(enumerate(args))):
         if arg.startswith("plugin_enable:"):
-            plugins_enabled.append(arg[len("plugin_enable:"):])
+            plugins_enabled.append(arg[len("plugin_enable:") :])
             del args[count]
 
     plugins_disabled = []
 
     for count, arg in reversed(tuple(enumerate(args))):
         if arg.startswith("plugin_disable:"):
-            plugins_disabled.append(arg[len("plugin_disable:"):])
+            plugins_disabled.append(arg[len("plugin_disable:") :])
             del args[count]
 
     recurse_not = []
 
     for count, arg in reversed(tuple(enumerate(args))):
         if arg.startswith("recurse_not:"):
-            recurse_not.append(arg[len("recurse_not:"):])
+            recurse_not.append(arg[len("recurse_not:") :])
             del args[count]
 
     recurse_to = []
 
     for count, arg in reversed(tuple(enumerate(args))):
         if arg.startswith("recurse_to:"):
-            recurse_to.append(arg[len("recurse_to:"):])
+            recurse_to.append(arg[len("recurse_to:") :])
             del args[count]
 
     if args:
-        sys.exit("Error, non understood mode(s) '%s'," % ','.join(args))
+        sys.exit("Error, non understood mode(s) '%s'," % ",".join(args))
 
     # In coverage mode, we don't want to execute, and to do this only in one mode,
     # we enable two step execution, which splits running the binary from the actual
@@ -220,7 +242,7 @@ def main():
     assert not recurse_all or not recurse_none
 
     if "PYTHONHASHSEED" not in os.environ:
-        os.environ["PYTHONHASHSEED"] = '0'
+        os.environ["PYTHONHASHSEED"] = "0"
 
     os.environ["PYTHONWARNINGS"] = "ignore"
 
@@ -237,8 +259,8 @@ def main():
             os.environ["PYTHON"] += "-dbg"
 
         if os.name == "nt":
-            if os.path.exists(os.environ["PYTHON"][:-4]+"_d.exe"):
-                os.environ["PYTHON"] = os.environ["PYTHON"][:-4]+"_d.exe"
+            if os.path.exists(os.environ["PYTHON"][:-4] + "_d.exe"):
+                os.environ["PYTHON"] = os.environ["PYTHON"][:-4] + "_d.exe"
 
     if os.environ["PYTHON"].endswith("-dbg"):
         python_debug = True
@@ -246,33 +268,29 @@ def main():
     if os.environ["PYTHON"].lower().endswith("_d.exe"):
         python_debug = True
 
-
     if comparison_mode:
         my_print(
             """\
-Comparing output of '{filename}' using '{python}' with flags {args} ...""".
-            format(
-                filename = filename,
-                python   = os.environ["PYTHON"],
-                args     = ", ".join(arguments)
+Comparing output of '{filename}' using '{python}' with flags {args} ...""".format(
+                filename=filename,
+                python=os.environ["PYTHON"],
+                args=", ".join(arguments),
             )
         )
     else:
         my_print(
             """\
-Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
-            format(
-                filename = filename,
-                python   = os.environ["PYTHON"],
-                args     = ", ".join(arguments)
+Taking coverage of '{filename}' using '{python}' with flags {args} ...""".format(
+                filename=filename,
+                python=os.environ["PYTHON"],
+                args=", ".join(arguments),
             )
         )
 
-
     if comparison_mode and not silent_mode:
-        my_print('*' * 80)
+        my_print("*" * 80)
         my_print("CPython:")
-        my_print('*' * 80)
+        my_print("*" * 80)
 
     if two_step_execution:
         filename = os.path.abspath(filename)
@@ -281,33 +299,25 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
         if no_warnings:
             cpython_cmd = [
                 os.environ["PYTHON"],
-                "-W", "ignore",
-                "-c", "import sys; sys.path.append(%s); import %s" % (
-                    repr(os.path.dirname(filename)),
-                    os.path.basename(filename)
-                )
+                "-W",
+                "ignore",
+                "-c",
+                "import sys; sys.path.append(%s); import %s"
+                % (repr(os.path.dirname(filename)), os.path.basename(filename)),
             ]
         else:
             cpython_cmd = [
                 os.environ["PYTHON"],
-                "-c", "import sys; sys.path.append(%s); import %s" % (
-                    repr(os.path.dirname(filename)),
-                    os.path.basename(filename)
-                )
+                "-c",
+                "import sys; sys.path.append(%s); import %s"
+                % (repr(os.path.dirname(filename)), os.path.basename(filename)),
             ]
 
     else:
         if no_warnings:
-            cpython_cmd = [
-                os.environ["PYTHON"],
-                "-W", "ignore",
-                filename
-            ]
+            cpython_cmd = [os.environ["PYTHON"], "-W", "ignore", filename]
         else:
-            cpython_cmd = [
-                os.environ["PYTHON"],
-                filename
-            ]
+            cpython_cmd = [os.environ["PYTHON"], filename]
 
     if no_site:
         cpython_cmd.insert(1, "-S")
@@ -322,7 +332,7 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
             nuitka_call = [
                 os.environ["PYTHON"],
                 "-m",
-                "nuitka.__main__", # Note: Needed for Python2.6
+                "nuitka.__main__",  # Note: Needed for Python2.6
             ]
         else:
             assert coverage_mode
@@ -337,7 +347,7 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
                 os.devnull,
                 "-a",
                 "-m",
-                "nuitka.__main__" # Note: Needed for Python2.6
+                "nuitka.__main__",  # Note: Needed for Python2.6
             ]
 
     if python_debug:
@@ -352,6 +362,9 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
     if original_file:
         extra_options.append("--file-reference-choice=original")
 
+    if runtime_file:
+        extra_options.append("--file-reference-choice=runtime")
+
     if full_compat:
         extra_options.append("--full-compat")
 
@@ -361,8 +374,8 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
         python_path = check_output(
             [
                 os.environ["PYTHON"],
-                "-c"
-                "import sys, os; print(os.pathsep.join(sys.path))"
+                "-c",
+                "import sys, os; print(os.pathsep.join(sys.path))",
             ]
         )
 
@@ -399,33 +412,30 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
     # Now build the command to run Nuitka.
     if not two_step_execution:
         if module_mode:
-            nuitka_cmd = nuitka_call + extra_options + \
-              ["--run", "--module", filename]
+            nuitka_cmd = nuitka_call + extra_options + ["--run", "--module", filename]
         elif standalone_mode:
-            nuitka_cmd = nuitka_call + extra_options + \
-              ["--run", "--standalone", filename]
+            nuitka_cmd = (
+                nuitka_call + extra_options + ["--run", "--standalone", filename]
+            )
         else:
-            nuitka_cmd = nuitka_call + extra_options + \
-              ["--run", filename]
+            nuitka_cmd = nuitka_call + extra_options + ["--run", filename]
 
         if no_site:
             nuitka_cmd.insert(len(nuitka_cmd) - 1, "--python-flag=-S")
 
     else:
         if module_mode:
-            nuitka_cmd1 = nuitka_call + extra_options + \
-              ["--module", os.path.abspath(filename)]
+            nuitka_cmd1 = (
+                nuitka_call + extra_options + ["--module", os.path.abspath(filename)]
+            )
         elif standalone_mode:
-            nuitka_cmd1 = nuitka_call + extra_options + \
-              ["--standalone", filename]
+            nuitka_cmd1 = nuitka_call + extra_options + ["--standalone", filename]
         else:
-            nuitka_cmd1 = nuitka_call + extra_options + \
-              [filename]
+            nuitka_cmd1 = nuitka_call + extra_options + [filename]
 
         if no_site:
             nuitka_cmd1.insert(len(nuitka_cmd1) - 1, "--python-flag=-S")
 
-
     for extra_option in extra_options:
         dir_match = re.search(r"--output-dir=(.*?)(\s|$)", extra_option)
 
@@ -434,13 +444,15 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
             break
     else:
         # The default.
-        output_dir = '.'
+        output_dir = "."
 
     if module_mode:
         nuitka_cmd2 = [
             os.environ["PYTHON"],
-            "-W", "ignore",
-            "-c", "import %s" % os.path.basename(filename)
+            "-W",
+            "ignore",
+            "-c",
+            "import %s" % os.path.basename(filename),
         ]
     else:
         exe_filename = os.path.basename(filename)
@@ -448,12 +460,10 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
         if filename.endswith(".py"):
             exe_filename = exe_filename[:-3]
 
-        exe_filename = exe_filename.replace(')', "").replace('(', "")
-        exe_filename += (".exe" if os.name == "nt" else ".bin")
+        exe_filename = exe_filename.replace(")", "").replace("(", "")
+        exe_filename += ".exe" if os.name == "nt" else ".bin"
 
-        nuitka_cmd2 = [
-            os.path.join(output_dir, exe_filename)
-        ]
+        nuitka_cmd2 = [os.path.join(output_dir, exe_filename)]
 
         pdb_filename = exe_filename[:-4] + ".pdb"
 
@@ -462,17 +472,16 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
 
     if comparison_mode:
         cpython_time, stdout_cpython, stderr_cpython, exit_cpython = getCPythonResults(
-            cpython_cmd    = cpython_cmd,
-            cpython_cached = cpython_cached
+            cpython_cmd=cpython_cmd, cpython_cached=cpython_cached
         )
 
     if comparison_mode and not silent_mode:
         displayOutput(stdout_cpython, stderr_cpython)
 
     if comparison_mode and not silent_mode:
-        my_print('*' * 80)
+        my_print("*" * 80)
         my_print("Nuitka:")
-        my_print('*' * 80)
+        my_print("*" * 80)
 
     if two_step_execution:
         if output_dir:
@@ -489,7 +498,8 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
         if trace_command:
             my_print("Going to output directory", os.getcwd())
 
-    start_time = time.time()
+    stop_watch = StopWatch()
+    stop_watch.start()
 
     if not two_step_execution:
         if trace_command:
@@ -500,16 +510,15 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
         for _i in range(5):
             with withPythonPathChange(nuitka_package_dir):
                 process = subprocess.Popen(
-                    args   = nuitka_cmd,
-                    stdout = subprocess.PIPE,
-                    stderr = subprocess.PIPE
+                    args=nuitka_cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE
                 )
 
             stdout_nuitka, stderr_nuitka = process.communicate()
             exit_nuitka = process.returncode
 
-            if checkNoPermissionError(stdout_nuitka) and \
-               checkNoPermissionError(stderr_nuitka):
+            if checkNoPermissionError(stdout_nuitka) and checkNoPermissionError(
+                stderr_nuitka
+            ):
                 break
 
             my_print("Retrying nuitka exe due to permission problems after delay.")
@@ -521,28 +530,26 @@ Taking coverage of '{filename}' using '{python}' with flags {args} ...""".
 
         with withPythonPathChange(nuitka_package_dir):
             process = subprocess.Popen(
-                args   = nuitka_cmd1,
-                stdout = subprocess.PIPE,
-                stderr = subprocess.PIPE
+                args=nuitka_cmd1, stdout=subprocess.PIPE, stderr=subprocess.PIPE
             )
 
         stdout_nuitka1, stderr_nuitka1 = process.communicate()
         exit_nuitka1 = process.returncode
 
         if exit_nuitka1 != 0:
-            if not expect_failure and \
-               not comparison_mode and \
-               not os.path.exists(".coverage"):
+            if (
+                not expect_failure
+                and not comparison_mode
+                and not os.path.exists(".coverage")
+            ):
                 sys.exit(
                     """\
 Error, failed to take coverage with '%s'.
 
 Stderr was:
 %s
-""" % (
-    os.environ["PYTHON"],
-    stderr_nuitka1
-)
+"""
+                    % (os.environ["PYTHON"], stderr_nuitka1)
                 )
 
             exit_nuitka = exit_nuitka1
@@ -554,9 +561,7 @@ Stderr was:
                     my_print("Nuitka command 2:", nuitka_cmd2)
 
                 process = subprocess.Popen(
-                    args   = nuitka_cmd2,
-                    stdout = subprocess.PIPE,
-                    stderr = subprocess.PIPE
+                    args=nuitka_cmd2, stdout=subprocess.PIPE, stderr=subprocess.PIPE
                 )
 
                 stdout_nuitka2, stderr_nuitka2 = process.communicate()
@@ -567,8 +572,8 @@ Stderr was:
                 exit_nuitka = exit_nuitka1
                 stdout_nuitka, stderr_nuitka = stdout_nuitka1, stderr_nuitka1
 
-
-    nuitka_time = time.time() - start_time
+    stop_watch.stop()
+    nuitka_time = stop_watch.delta()
 
     if not silent_mode:
         displayOutput(stdout_nuitka, stderr_nuitka)
@@ -584,7 +589,7 @@ Stderr was:
             stdout_nuitka,
             ignore_warnings,
             ignore_infos,
-            syntax_errors
+            syntax_errors,
         )
 
         if ignore_stderr:
@@ -596,7 +601,7 @@ Stderr was:
                 stderr_nuitka,
                 ignore_warnings,
                 ignore_infos,
-                syntax_errors
+                syntax_errors,
             )
 
         exit_code_return = exit_cpython != exit_nuitka
@@ -605,25 +610,23 @@ Stderr was:
             my_print(
                 """\
 Exit codes {exit_cpython:d} (CPython) != {exit_nuitka:d} (Nuitka)""".format(
-                    exit_cpython = exit_cpython,
-                    exit_nuitka  = exit_nuitka
+                    exit_cpython=exit_cpython, exit_nuitka=exit_nuitka
                 )
             )
 
         # In case of segfault, also output the call stack by entering debugger
         # without stdin forwarded.
-        if exit_code_return and \
-           exit_nuitka == -11 and \
-           sys.platform != "nt" and \
-           not module_mode and \
-           not two_step_execution:
+        if (
+            exit_code_return
+            and exit_nuitka == -11
+            and sys.platform != "nt"
+            and not module_mode
+            and not two_step_execution
+        ):
             nuitka_cmd.insert(len(nuitka_cmd) - 1, "--debugger")
 
             with withPythonPathChange(nuitka_package_dir):
-                process = subprocess.Popen(
-                    args  = nuitka_cmd,
-                    stdin = subprocess.PIPE
-                )
+                process = subprocess.Popen(args=nuitka_cmd, stdin=subprocess.PIPE)
 
             process.communicate()
 
@@ -648,19 +651,19 @@ Exit codes {exit_cpython:d} (CPython) != {exit_nuitka:d} (Nuitka)""".format(
                     # It appears there is a tiny lock race that we randomly cause,
                     # likely because --run spawns a subprocess that might still
                     # be doing the cleanup work.
-                    if os.path.exists(nuitka_cmd2[0]+".away"):
-                        os.unlink(nuitka_cmd2[0]+".away")
+                    if os.path.exists(nuitka_cmd2[0] + ".away"):
+                        os.unlink(nuitka_cmd2[0] + ".away")
 
                     for _i in range(10):
                         try:
-                            os.rename(nuitka_cmd2[0], nuitka_cmd2[0]+".away")
+                            os.rename(nuitka_cmd2[0], nuitka_cmd2[0] + ".away")
                         except OSError:
                             time.sleep(0.1)
                             continue
 
                     for _i in range(10):
                         try:
-                            os.unlink(nuitka_cmd2[0]+".away")
+                            os.unlink(nuitka_cmd2[0] + ".away")
                         except OSError:
                             time.sleep(2)
                             continue
@@ -680,38 +683,21 @@ Exit codes {exit_cpython:d} (CPython) != {exit_nuitka:d} (Nuitka)""".format(
             if os.path.exists(module_filename):
                 os.unlink(module_filename)
 
-
     if comparison_mode and timing:
-        my_print(
-            "CPython took %.2fs vs %0.2fs Nuitka." % (
-                cpython_time,
-                nuitka_time
-            )
-        )
+        my_print("CPython took %.2fs vs %0.2fs Nuitka." % (cpython_time, nuitka_time))
 
     if comparison_mode and not silent_mode:
         my_print("OK, same outputs.")
 
 
 nuitka_package_dir = os.path.normpath(
-    os.path.abspath(
-        os.path.join(
-            os.path.dirname(__file__),
-            "..",
-            "..",
-            "..",
-            "..",
-        )
-    )
+    os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "..", "..", ".."))
 )
 
 
 if __name__ == "__main__":
     # Unchanged, running from checkout, use the parent directory, the nuitka
     # package ought be there.
-    sys.path.insert(
-        0,
-        nuitka_package_dir
-    )
+    sys.path.insert(0, nuitka_package_dir)
 
     main()
