@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -22,11 +22,10 @@ source code comments with developer manual sections.
 
 """
 from nuitka.nodes.BuiltinRefNodes import ExpressionBuiltinExceptionRef
-from nuitka.nodes.ConditionalNodes import StatementConditional
+from nuitka.nodes.ConditionalNodes import makeStatementConditional
 from nuitka.nodes.ContainerMakingNodes import ExpressionMakeTuple
 from nuitka.nodes.ExceptionNodes import StatementRaiseException
 from nuitka.nodes.OperatorNodes import ExpressionOperationNOT
-from nuitka.nodes.StatementNodes import StatementsSequence
 from nuitka.Options import getPythonFlags
 from nuitka.PythonVersions import python_version
 
@@ -55,32 +54,24 @@ def buildAssertNode(provider, node, source_ref):
 
     if exception_value is not None and python_version > 272:
         exception_value = ExpressionMakeTuple(
-            elements   = (exception_value,),
-            source_ref = source_ref
+            elements=(exception_value,), source_ref=source_ref
         )
 
     raise_statement = StatementRaiseException(
-        exception_type  = ExpressionBuiltinExceptionRef(
-            exception_name = "AssertionError",
-            source_ref     = source_ref
+        exception_type=ExpressionBuiltinExceptionRef(
+            exception_name="AssertionError", source_ref=source_ref
         ),
-        exception_value = exception_value,
-        exception_trace = None,
-        exception_cause = None,
-        source_ref      = source_ref
+        exception_value=exception_value,
+        exception_trace=None,
+        exception_cause=None,
+        source_ref=source_ref,
     )
 
-    return StatementConditional(
-        condition  = ExpressionOperationNOT(
-            operand    = buildNode(provider, node.test, source_ref),
-            source_ref = source_ref
+    return makeStatementConditional(
+        condition=ExpressionOperationNOT(
+            operand=buildNode(provider, node.test, source_ref), source_ref=source_ref
         ),
-        yes_branch = StatementsSequence(
-            statements = (
-                raise_statement,
-            ),
-            source_ref = source_ref
-        ),
-        no_branch  = None,
-        source_ref = source_ref
+        yes_branch=raise_statement,
+        no_branch=None,
+        source_ref=source_ref,
     )
