@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -24,7 +24,7 @@ source code comments with developer manual sections.
 
 from nuitka.nodes.AssignNodes import (
     StatementAssignmentVariable,
-    StatementReleaseVariable
+    StatementReleaseVariable,
 )
 from nuitka.nodes.ComparisonNodes import makeComparisonExpression
 from nuitka.nodes.ConditionalNodes import makeStatementConditional
@@ -34,18 +34,12 @@ from nuitka.nodes.ReturnNodes import StatementReturn
 from nuitka.nodes.VariableRefNodes import ExpressionTempVariableRef
 
 from .ReformulationTryFinallyStatements import makeTryFinallyStatement
-from .TreeHelpers import (
-    buildNode,
-    getKind,
-    makeStatementsSequenceFromStatement
-)
+from .TreeHelpers import buildNode, getKind, makeStatementsSequenceFromStatement
 
 
 def _makeComparisonNode(left, right, comparator, source_ref):
     result = makeComparisonExpression(left, right, comparator, source_ref)
-    result.setCompatibleSourceReference(
-        source_ref = right.getCompatibleSourceReference()
-    )
+    result.setCompatibleSourceReference(source_ref=right.getCompatibleSourceReference())
 
     return result
 
@@ -62,28 +56,21 @@ def buildComparisonNode(provider, node, source_ref):
     # The operands are split out in two parts strangely.
     left = buildNode(provider, node.left, source_ref)
     rights = [
-        buildNode(provider, comparator, source_ref)
-        for comparator in
-        node.comparators
-    ]
-    comparators = [
-        getKind(comparator)
-        for comparator in
-        node.ops
+        buildNode(provider, comparator, source_ref) for comparator in node.comparators
     ]
+    comparators = [getKind(comparator) for comparator in node.ops]
     # Normal, and simple case, we only have one comparison, which is what our
     # node handles only. Then we can handle it
     if len(rights) == 1:
         return _makeComparisonNode(
-            left       = left,
-            right      = rights[0],
+            left=left,
+            right=rights[0],
             # TODO: The terminology of Nuitka might be messed up here.
-            comparator = comparators[0],
-            source_ref = source_ref
+            comparator=comparators[0],
+            source_ref=source_ref,
         )
 
-    return buildComplexComparisonNode(provider, left, rights, comparators,
-                                      source_ref)
+    return buildComplexComparisonNode(provider, left, rights, comparators, source_ref)
 
 
 def buildComplexComparisonNode(provider, left, rights, comparators, source_ref):
@@ -91,67 +78,52 @@ def buildComplexComparisonNode(provider, left, rights, comparators, source_ref):
     # This is a bit complex, due to the many details, pylint: disable=too-many-locals
 
     outline_body = ExpressionOutlineBody(
-        provider   = provider,
-        name       = "comparison_chain",
-        source_ref = source_ref
+        provider=provider, name="comparison_chain", source_ref=source_ref
     )
 
     variables = [
-        outline_body.allocateTempVariable(
-            temp_scope = None,
-            name       = "operand_%d" % count
-        )
-        for count in
-        range(2, len(rights)+2)
+        outline_body.allocateTempVariable(temp_scope=None, name="operand_%d" % count)
+        for count in range(2, len(rights) + 2)
     ]
 
     tmp_variable = outline_body.allocateTempVariable(
-        temp_scope = None,
-        name       = "comparison_result"
+        temp_scope=None, name="comparison_result"
     )
 
     def makeTempAssignment(count, value):
         return StatementAssignmentVariable(
-            variable   = variables[count],
-            source     = value,
-            source_ref = source_ref,
+            variable=variables[count], source=value, source_ref=source_ref
         )
 
     def makeReleaseStatement(count):
         return StatementReleaseVariable(
-            variable   = variables[count],
-            source_ref = source_ref
+            variable=variables[count], source_ref=source_ref
         )
 
     def makeValueComparisonReturn(left, right, comparator):
         yield StatementAssignmentVariable(
-            variable   = tmp_variable,
-            source     = _makeComparisonNode(
-                left       = left,
-                right      = right,
-                comparator = comparator,
-                source_ref = source_ref
+            variable=tmp_variable,
+            source=_makeComparisonNode(
+                left=left, right=right, comparator=comparator, source_ref=source_ref
             ),
-            source_ref = source_ref,
+            source_ref=source_ref,
         )
 
         yield makeStatementConditional(
-            condition  = ExpressionOperationNOT(
-                operand    = ExpressionTempVariableRef(
-                    variable   = tmp_variable,
-                    source_ref = source_ref
+            condition=ExpressionOperationNOT(
+                operand=ExpressionTempVariableRef(
+                    variable=tmp_variable, source_ref=source_ref
                 ),
-                source_ref = source_ref
+                source_ref=source_ref,
             ),
-            yes_branch = StatementReturn(
-                expression = ExpressionTempVariableRef(
-                    variable   = tmp_variable,
-                    source_ref = source_ref
+            yes_branch=StatementReturn(
+                expression=ExpressionTempVariableRef(
+                    variable=tmp_variable, source_ref=source_ref
                 ),
-                source_ref = source_ref
+                source_ref=source_ref,
             ),
-            no_branch  = None,
-            source_ref = source_ref
+            no_branch=None,
+            source_ref=source_ref,
         )
 
     statements = []
@@ -159,61 +131,46 @@ def buildComplexComparisonNode(provider, left, rights, comparators, source_ref):
 
     for count, value in enumerate(rights):
         if value is not rights[-1]:
-            statements.append(
-                makeTempAssignment(count, value)
-            )
-            final.append(
-                makeReleaseStatement(count)
-            )
+            statements.append(makeTempAssignment(count, value))
+            final.append(makeReleaseStatement(count))
             right = ExpressionTempVariableRef(
-                variable   = variables[count],
-                source_ref = source_ref
+                variable=variables[count], source_ref=source_ref
             )
         else:
             right = value
 
         if count != 0:
             left = ExpressionTempVariableRef(
-                variable   = variables[count-1],
-                source_ref = source_ref
+                variable=variables[count - 1], source_ref=source_ref
             )
 
         comparator = comparators[count]
 
         if value is not rights[-1]:
-            statements.extend(
-                makeValueComparisonReturn(
-                    left,
-                    right,
-                    comparator
-                )
-            )
+            statements.extend(makeValueComparisonReturn(left, right, comparator))
         else:
             statements.append(
                 StatementReturn(
-                    expression = _makeComparisonNode(
-                        left       = left,
-                        right      = right,
-                        comparator = comparator,
-                        source_ref = source_ref
+                    expression=_makeComparisonNode(
+                        left=left,
+                        right=right,
+                        comparator=comparator,
+                        source_ref=source_ref,
                     ),
-                    source_ref = source_ref
+                    source_ref=source_ref,
                 )
             )
             final.append(
-                StatementReleaseVariable(
-                    variable   = tmp_variable,
-                    source_ref = source_ref
-                )
+                StatementReleaseVariable(variable=tmp_variable, source_ref=source_ref)
             )
 
     outline_body.setBody(
         makeStatementsSequenceFromStatement(
-            statement = makeTryFinallyStatement(
-                provider   = outline_body,
-                tried      = statements,
-                final      = final,
-                source_ref = source_ref
+            statement=makeTryFinallyStatement(
+                provider=outline_body,
+                tried=statements,
+                final=final,
+                source_ref=source_ref,
             )
         )
     )
