@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -25,7 +25,7 @@ source code comments with developer manual sections.
 from nuitka.nodes.AssignNodes import (
     StatementAssignmentVariable,
     StatementAssignmentVariableName,
-    StatementReleaseVariable
+    StatementReleaseVariable,
 )
 from nuitka.nodes.ConstantRefNodes import makeConstantRefNode
 from nuitka.nodes.FutureSpecs import FutureSpec
@@ -34,7 +34,7 @@ from nuitka.nodes.ImportNodes import (
     ExpressionBuiltinImport,
     ExpressionImportModuleHard,
     ExpressionImportName,
-    StatementImportStar
+    StatementImportStar,
 )
 from nuitka.nodes.NodeMakingHelpers import mergeStatements
 from nuitka.nodes.StatementNodes import StatementsSequence
@@ -49,6 +49,7 @@ from .TreeHelpers import makeStatementsSequenceOrStatement, mangleName
 # of the file.
 _future_import_nodes = []
 
+
 def checkFutureImportsOnlyAtStart(body):
     # Check if a __future__ imports really were at the beginning of the file.
     for node in body:
@@ -61,42 +62,41 @@ def checkFutureImportsOnlyAtStart(body):
 from __future__ imports must occur at the beginning of the file""",
                     _future_import_nodes[0].source_ref.atColumnNumber(
                         _future_import_nodes[0].col_offset
-                    )
-
+                    ),
                 )
 
+
 def _handleFutureImport(provider, node, source_ref):
     # Don't allow future imports in functions or classes.
     if not provider.isCompiledPythonModule():
         raiseSyntaxError(
             """\
 from __future__ imports must occur at the beginning of the file""",
-            source_ref.atColumnNumber(node.col_offset)
+            source_ref.atColumnNumber(node.col_offset),
         )
 
-
     for import_desc in node.names:
         object_name, _local_name = import_desc.name, import_desc.asname
 
-        _enableFutureFeature(
-            node        = node,
-            object_name = object_name,
-            source_ref  = source_ref
-        )
+        _enableFutureFeature(node=node, object_name=object_name, source_ref=source_ref)
 
     # Remember it for checks to be applied once module is complete, e.g. if
     # they are all at module start.
     node.source_ref = source_ref
     _future_import_nodes.append(node)
 
+
 _future_specs = []
 
+
 def pushFutureSpec():
     _future_specs.append(FutureSpec())
 
+
 def getFutureSpec():
     return _future_specs[-1]
 
+
 def popFutureSpec():
     del _future_specs[-1]
 
@@ -117,17 +117,16 @@ def _enableFutureFeature(node, object_name, source_ref):
     elif object_name == "generator_stop":
         future_spec.enableGeneratorStop()
     elif object_name == "braces":
-        raiseSyntaxError(
-            "not a chance",
-            source_ref.atColumnNumber(node.col_offset)
-        )
+        raiseSyntaxError("not a chance", source_ref.atColumnNumber(node.col_offset))
     elif object_name in ("nested_scopes", "generators", "with_statement"):
         # These are enabled in all cases already.
         pass
+    elif object_name == "annotations" and python_version >= 370:
+        future_spec.enableFutureAnnotations()
     else:
         raiseSyntaxError(
             "future feature %s is not defined" % object_name,
-            source_ref.atColumnNumber(node.col_offset)
+            source_ref.atColumnNumber(node.col_offset),
         )
 
 
@@ -164,15 +163,11 @@ def buildImportFromNode(provider, node, source_ref):
     for import_desc in node.names:
         object_name, local_name = import_desc.name, import_desc.asname
 
-        if object_name == '*':
+        if object_name == "*":
             target_names.append(None)
             assert local_name is None
         else:
-            target_names.append(
-                local_name
-                  if local_name is not None else
-                object_name
-            )
+            target_names.append(local_name if local_name is not None else object_name)
 
         import_names.append(object_name)
 
@@ -188,7 +183,7 @@ def buildImportFromNode(provider, node, source_ref):
         if not provider.isCompiledPythonModule() and python_version >= 300:
             raiseSyntaxError(
                 "import * only allowed at module level",
-                source_ref.atColumnNumber(node.col_offset)
+                source_ref.atColumnNumber(node.col_offset),
             )
 
         if provider.isCompiledPythonModule():
@@ -199,31 +194,32 @@ def buildImportFromNode(provider, node, source_ref):
             import_locals = makeConstantRefNode({}, source_ref, True)
 
         return StatementImportStar(
-            locals_scope  = provider.getFunctionLocalsScope(),
-            module_import = ExpressionBuiltinImport(
-                name        = makeConstantRefNode(module_name, source_ref, True),
-                globals_arg = import_globals,
-                locals_arg  = import_locals,
-                fromlist    = makeConstantRefNode(('*',), source_ref, True),
-                level       = level_obj,
-                source_ref  = source_ref
+            target_scope=provider.getModuleDictScope()
+            if provider.isCompiledPythonModule()
+            else provider.getFunctionLocalsScope(),
+            module_import=ExpressionBuiltinImport(
+                name=makeConstantRefNode(module_name, source_ref, True),
+                globals_arg=import_globals,
+                locals_arg=import_locals,
+                fromlist=makeConstantRefNode(("*",), source_ref, True),
+                level=level_obj,
+                source_ref=source_ref,
             ),
-            source_ref    = source_ref
+            source_ref=source_ref,
         )
     else:
         if module_name == "__future__":
             imported_from_module = ExpressionImportModuleHard(
-                module_name = "__future__",
-                source_ref  = source_ref
+                module_name="__future__", source_ref=source_ref
             )
         else:
             imported_from_module = ExpressionBuiltinImport(
-                name        = makeConstantRefNode(module_name, source_ref, True),
-                globals_arg = ExpressionBuiltinGlobals(source_ref),
-                locals_arg  = makeConstantRefNode(None, source_ref, True),
-                fromlist    = makeConstantRefNode(tuple(import_names), source_ref, True),
-                level       = level_obj,
-                source_ref  = source_ref
+                name=makeConstantRefNode(module_name, source_ref, True),
+                globals_arg=ExpressionBuiltinGlobals(source_ref),
+                locals_arg=makeConstantRefNode(None, source_ref, True),
+                fromlist=makeConstantRefNode(tuple(import_names), source_ref, True),
+                level=level_obj,
+                source_ref=source_ref,
             )
 
         # If we have multiple names to import, consider each.
@@ -233,21 +229,19 @@ def buildImportFromNode(provider, node, source_ref):
 
         if multi_names:
             tmp_import_from = provider.allocateTempVariable(
-                temp_scope = provider.allocateTempScope("import_from"),
-                name       = "module"
+                temp_scope=provider.allocateTempScope("import_from"), name="module"
             )
 
             statements.append(
                 StatementAssignmentVariable(
-                    variable   = tmp_import_from,
-                    source     = imported_from_module,
-                    source_ref = source_ref
+                    variable=tmp_import_from,
+                    source=imported_from_module,
+                    source_ref=source_ref,
                 )
             )
 
             imported_from_module = ExpressionTempVariableRef(
-                variable   = tmp_import_from,
-                source_ref = source_ref
+                variable=tmp_import_from, source_ref=source_ref
             )
 
         import_statements = []
@@ -262,15 +256,15 @@ def buildImportFromNode(provider, node, source_ref):
 
             import_statements.append(
                 StatementAssignmentVariableName(
-                    provider      = provider,
-                    variable_name = mangleName(target_name, provider),
-                    source        = ExpressionImportName(
-                        module      = imported_from_module,
-                        import_name = import_name,
-                        level       = level,
-                        source_ref  = source_ref
+                    provider=provider,
+                    variable_name=mangleName(target_name, provider),
+                    source=ExpressionImportName(
+                        module=imported_from_module,
+                        import_name=import_name,
+                        level=level,
+                        source_ref=source_ref,
                     ),
-                    source_ref    = source_ref
+                    source_ref=source_ref,
                 )
             )
 
@@ -278,15 +272,14 @@ def buildImportFromNode(provider, node, source_ref):
         if multi_names:
             statements.append(
                 makeTryFinallyStatement(
-                    provider   = provider,
-                    tried      = import_statements,
-                    final      = (
+                    provider=provider,
+                    tried=import_statements,
+                    final=(
                         StatementReleaseVariable(
-                            variable   = tmp_import_from,
-                            source_ref = source_ref
+                            variable=tmp_import_from, source_ref=source_ref
                         ),
                     ),
-                    source_ref = source_ref
+                    source_ref=source_ref,
                 )
             )
         else:
@@ -296,8 +289,7 @@ def buildImportFromNode(provider, node, source_ref):
         # later one is not undoing previous ones. We can therefore have a
         # sequence of imports that each only import one thing therefore.
         return StatementsSequence(
-            statements = mergeStatements(statements),
-            source_ref = source_ref
+            statements=mergeStatements(statements), source_ref=source_ref
         )
 
 
@@ -305,10 +297,8 @@ def buildImportModulesNode(provider, node, source_ref):
     # Import modules statement. As described in the developer manual, these
     # statements can be treated as several ones.
 
-    import_names   = [
-        ( import_desc.name, import_desc.asname )
-        for import_desc in
-        node.names
+    import_names = [
+        (import_desc.name, import_desc.asname) for import_desc in node.names
     ]
 
     import_nodes = []
@@ -316,30 +306,34 @@ def buildImportModulesNode(provider, node, source_ref):
     for import_desc in import_names:
         module_name, local_name = import_desc
 
-        module_topname = module_name.split('.')[0]
+        module_topname = module_name.split(".")[0]
 
         # Note: The "level" of import is influenced by the future absolute
         # imports.
-        level = makeConstantRefNode(0, source_ref, True) if _future_specs[-1].isAbsoluteImport() else None
+        level = (
+            makeConstantRefNode(0, source_ref, True)
+            if _future_specs[-1].isAbsoluteImport()
+            else None
+        )
 
         import_node = ExpressionBuiltinImport(
-            name        = makeConstantRefNode(module_name, source_ref, True),
-            globals_arg = ExpressionBuiltinGlobals(source_ref),
-            locals_arg  = makeConstantRefNode(None, source_ref, True),
-            fromlist    = makeConstantRefNode(None, source_ref, True),
-            level       = level,
-            source_ref  = source_ref
+            name=makeConstantRefNode(module_name, source_ref, True),
+            globals_arg=ExpressionBuiltinGlobals(source_ref),
+            locals_arg=makeConstantRefNode(None, source_ref, True),
+            fromlist=makeConstantRefNode(None, source_ref, True),
+            level=level,
+            source_ref=source_ref,
         )
 
         if local_name:
             # If is gets a local name, the real name must be used as a
             # temporary value only, being looked up recursively.
-            for import_name in module_name.split('.')[1:]:
+            for import_name in module_name.split(".")[1:]:
                 import_node = ExpressionImportName(
-                    module      = import_node,
-                    import_name = import_name,
-                    level       = None,
-                    source_ref  = source_ref
+                    module=import_node,
+                    import_name=import_name,
+                    level=None,
+                    source_ref=source_ref,
                 )
 
         # If a name was given, use the one provided, otherwise the import gives
@@ -348,15 +342,12 @@ def buildImportModulesNode(provider, node, source_ref):
 
         import_nodes.append(
             StatementAssignmentVariableName(
-                provider      = provider,
-                variable_name = mangleName(
-                    local_name
-                      if local_name is not None else
-                    module_topname,
-                    provider
+                provider=provider,
+                variable_name=mangleName(
+                    local_name if local_name is not None else module_topname, provider
                 ),
-                source        = import_node,
-                source_ref    = source_ref
+                source=import_node,
+                source_ref=source_ref,
             )
         )
 
@@ -364,6 +355,5 @@ def buildImportModulesNode(provider, node, source_ref):
     # failure of a later one is not changing that one bit . We can therefore
     # have a sequence of imports that only import one thing therefore.
     return makeStatementsSequenceOrStatement(
-        statements = import_nodes,
-        source_ref = source_ref
+        statements=import_nodes, source_ref=source_ref
     )
