@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -25,52 +25,46 @@ source code comments with developer manual sections.
 from nuitka import Options
 from nuitka.nodes.AssignNodes import (
     StatementAssignmentVariable,
-    StatementReleaseVariable
+    StatementReleaseVariable,
 )
 from nuitka.nodes.AttributeNodes import (
     ExpressionAttributeLookup,
-    ExpressionAttributeLookupSpecial
-)
-from nuitka.nodes.CallNodes import (
-    ExpressionCallEmpty,
-    ExpressionCallNoKeywords
+    ExpressionAttributeLookupSpecial,
 )
+from nuitka.nodes.CallNodes import ExpressionCallEmpty, ExpressionCallNoKeywords
 from nuitka.nodes.ComparisonNodes import ExpressionComparisonIs
 from nuitka.nodes.ConditionalNodes import makeStatementConditional
 from nuitka.nodes.ConstantRefNodes import makeConstantRefNode
 from nuitka.nodes.ContainerMakingNodes import ExpressionMakeTuple
 from nuitka.nodes.CoroutineNodes import (
     ExpressionAsyncWaitEnter,
-    ExpressionAsyncWaitExit
+    ExpressionAsyncWaitExit,
 )
 from nuitka.nodes.ExceptionNodes import (
     ExpressionCaughtExceptionTracebackRef,
     ExpressionCaughtExceptionTypeRef,
-    ExpressionCaughtExceptionValueRef
-)
-from nuitka.nodes.StatementNodes import (
-    StatementExpressionOnly,
-    StatementsSequence
+    ExpressionCaughtExceptionValueRef,
 )
+from nuitka.nodes.StatementNodes import StatementExpressionOnly, StatementsSequence
 from nuitka.nodes.VariableRefNodes import ExpressionTempVariableRef
+from nuitka.nodes.YieldNodes import ExpressionYieldFromWaitable
 from nuitka.PythonVersions import python_version
 
 from .ReformulationAssignmentStatements import buildAssignmentStatements
-from .ReformulationTryExceptStatements import (
-    makeTryExceptSingleHandlerNodeWithPublish
-)
+from .ReformulationTryExceptStatements import makeTryExceptSingleHandlerNodeWithPublish
 from .ReformulationTryFinallyStatements import makeTryFinallyStatement
 from .TreeHelpers import (
     buildNode,
     buildStatementsNode,
     getKind,
     makeReraiseExceptionStatement,
-    makeStatementsSequence
+    makeStatementsSequence,
 )
 
 
-def _buildWithNode(provider, context_expr, assign_target, body, body_lineno,
-                   sync, source_ref):
+def _buildWithNode(
+    provider, context_expr, assign_target, body, body_lineno, sync, source_ref
+):
     # Many details, pylint: disable=too-many-locals
     with_source = buildNode(provider, context_expr, source_ref)
 
@@ -80,40 +74,33 @@ def _buildWithNode(provider, context_expr, assign_target, body, body_lineno,
     temp_scope = provider.allocateTempScope("with")
 
     tmp_source_variable = provider.allocateTempVariable(
-        temp_scope = temp_scope,
-        name       = "source"
+        temp_scope=temp_scope, name="source"
     )
     tmp_exit_variable = provider.allocateTempVariable(
-        temp_scope = temp_scope,
-        name       = "exit"
+        temp_scope=temp_scope, name="exit"
     )
     tmp_enter_variable = provider.allocateTempVariable(
-        temp_scope = temp_scope,
-        name       = "enter"
+        temp_scope=temp_scope, name="enter"
     )
     tmp_indicator_variable = provider.allocateTempVariable(
-        temp_scope = temp_scope,
-        name       = "indicator"
+        temp_scope=temp_scope, name="indicator"
     )
 
     statements = (
         buildAssignmentStatements(
-            provider   = provider,
-            node       = assign_target,
-            allow_none = True,
-            source     = ExpressionTempVariableRef(
-                variable   = tmp_enter_variable,
-                source_ref = source_ref
+            provider=provider,
+            node=assign_target,
+            allow_none=True,
+            source=ExpressionTempVariableRef(
+                variable=tmp_enter_variable, source_ref=source_ref
             ),
-            source_ref = source_ref
+            source_ref=source_ref,
         ),
-        body
+        body,
     )
 
     with_body = makeStatementsSequence(
-        statements = statements,
-        allow_none = True,
-        source_ref = source_ref
+        statements=statements, allow_none=True, source_ref=source_ref
     )
 
     if Options.isFullCompat():
@@ -137,72 +124,64 @@ def _buildWithNode(provider, context_expr, assign_target, body, body_lineno,
         attribute_lookup_class = ExpressionAttributeLookupSpecial
 
     enter_value = ExpressionCallEmpty(
-        called     = attribute_lookup_class(
-            source         = ExpressionTempVariableRef(
-                variable   = tmp_source_variable,
-                source_ref = source_ref
+        called=attribute_lookup_class(
+            source=ExpressionTempVariableRef(
+                variable=tmp_source_variable, source_ref=source_ref
             ),
-            attribute_name = "__enter__" if sync else "__aenter__",
-            source_ref     = source_ref
+            attribute_name="__enter__" if sync else "__aenter__",
+            source_ref=source_ref,
         ),
-        source_ref = source_ref
+        source_ref=source_ref,
     )
 
     exit_value_exception = ExpressionCallNoKeywords(
-        called     = ExpressionTempVariableRef(
-            variable   = tmp_exit_variable,
-            source_ref = with_exit_source_ref
+        called=ExpressionTempVariableRef(
+            variable=tmp_exit_variable, source_ref=with_exit_source_ref
         ),
-        args       = ExpressionMakeTuple(
-            elements   = (
-                ExpressionCaughtExceptionTypeRef(
-                    source_ref = with_exit_source_ref
-                ),
-                ExpressionCaughtExceptionValueRef(
-                    source_ref = with_exit_source_ref
-                ),
-                ExpressionCaughtExceptionTracebackRef(
-                    source_ref = source_ref
-                ),
+        args=ExpressionMakeTuple(
+            elements=(
+                ExpressionCaughtExceptionTypeRef(source_ref=with_exit_source_ref),
+                ExpressionCaughtExceptionValueRef(source_ref=with_exit_source_ref),
+                ExpressionCaughtExceptionTracebackRef(source_ref=source_ref),
             ),
-            source_ref = source_ref
+            source_ref=source_ref,
         ),
-        source_ref = with_exit_source_ref
+        source_ref=with_exit_source_ref,
     )
 
     exit_value_no_exception = ExpressionCallNoKeywords(
-        called     = ExpressionTempVariableRef(
-            variable   = tmp_exit_variable,
-            source_ref = source_ref
+        called=ExpressionTempVariableRef(
+            variable=tmp_exit_variable, source_ref=source_ref
         ),
-        args       = makeConstantRefNode(
-            constant   = (None, None, None),
-            source_ref = source_ref
-        ),
-        source_ref = with_exit_source_ref
+        args=makeConstantRefNode(constant=(None, None, None), source_ref=source_ref),
+        source_ref=with_exit_source_ref,
     )
 
     # For "async with", await the entered value and exit value must be awaited.
     if not sync:
-        enter_value = ExpressionAsyncWaitEnter(
-            expression = enter_value,
-            source_ref = source_ref
+        enter_value = ExpressionYieldFromWaitable(
+            expression=ExpressionAsyncWaitEnter(
+                expression=enter_value, source_ref=source_ref
+            ),
+            source_ref=source_ref,
         )
-        exit_value_exception = ExpressionAsyncWaitExit(
-            expression = exit_value_exception,
-            source_ref = source_ref
+        exit_value_exception = ExpressionYieldFromWaitable(
+            expression=ExpressionAsyncWaitExit(
+                expression=exit_value_exception, source_ref=source_ref
+            ),
+            source_ref=source_ref,
         )
-        exit_value_no_exception = ExpressionAsyncWaitExit(
-            expression = exit_value_no_exception,
-            source_ref = source_ref
+        exit_value_no_exception = ExpressionYieldFromWaitable(
+            ExpressionAsyncWaitExit(
+                expression=exit_value_no_exception, source_ref=source_ref
+            ),
+            source_ref=source_ref,
         )
 
     statements = [
         # First assign the with context to a temporary variable.
         StatementAssignmentVariable(
-            variable   = tmp_source_variable,
-            source     = with_source,
-            source_ref = source_ref
+            variable=tmp_source_variable, source=with_source, source_ref=source_ref
         )
     ]
 
@@ -210,22 +189,19 @@ def _buildWithNode(provider, context_expr, assign_target, body, body_lineno,
         # Next, assign "__enter__" and "__exit__" attributes to temporary
         # variables.
         StatementAssignmentVariable(
-            variable   = tmp_exit_variable,
-            source     = attribute_lookup_class(
-                source         = ExpressionTempVariableRef(
-                    variable   = tmp_source_variable,
-                    source_ref = source_ref
+            variable=tmp_exit_variable,
+            source=attribute_lookup_class(
+                source=ExpressionTempVariableRef(
+                    variable=tmp_source_variable, source_ref=source_ref
                 ),
-                attribute_name = "__exit__" if sync else "__aexit__",
-                source_ref     = source_ref
+                attribute_name="__exit__" if sync else "__aexit__",
+                source_ref=source_ref,
             ),
-            source_ref = source_ref
+            source_ref=source_ref,
         ),
         StatementAssignmentVariable(
-            variable   = tmp_enter_variable,
-            source     = enter_value,
-            source_ref = source_ref
-        )
+            variable=tmp_enter_variable, source=enter_value, source_ref=source_ref
+        ),
     ]
 
     if python_version >= 360 and sync:
@@ -235,93 +211,80 @@ def _buildWithNode(provider, context_expr, assign_target, body, body_lineno,
 
     statements.append(
         StatementAssignmentVariable(
-            variable   = tmp_indicator_variable,
-            source     = makeConstantRefNode(
-                constant   = True,
-                source_ref = source_ref
-            ),
-            source_ref = source_ref
+            variable=tmp_indicator_variable,
+            source=makeConstantRefNode(constant=True, source_ref=source_ref),
+            source_ref=source_ref,
         )
     )
 
     statements += [
         makeTryFinallyStatement(
-            provider   = provider,
-            tried      = makeTryExceptSingleHandlerNodeWithPublish(
-                provider       = provider,
-                tried          = with_body,
-                exception_name = "BaseException",
-                handler_body   = StatementsSequence(
-                    statements = (
+            provider=provider,
+            tried=makeTryExceptSingleHandlerNodeWithPublish(
+                provider=provider,
+                tried=with_body,
+                exception_name="BaseException",
+                handler_body=StatementsSequence(
+                    statements=(
                         # Prevents final block from calling __exit__ as
                         # well.
                         StatementAssignmentVariable(
-                            variable   = tmp_indicator_variable,
-                            source     = makeConstantRefNode(
-                                constant   = False,
-                                source_ref = source_ref
+                            variable=tmp_indicator_variable,
+                            source=makeConstantRefNode(
+                                constant=False, source_ref=source_ref
                             ),
-                            source_ref = source_ref
+                            source_ref=source_ref,
                         ),
                         makeStatementConditional(
-                            condition  = exit_value_exception,
-                            no_branch  = makeReraiseExceptionStatement(
-                                source_ref = with_exit_source_ref
+                            condition=exit_value_exception,
+                            no_branch=makeReraiseExceptionStatement(
+                                source_ref=with_exit_source_ref
                             ),
-                            yes_branch = None,
-                            source_ref = with_exit_source_ref
+                            yes_branch=None,
+                            source_ref=with_exit_source_ref,
                         ),
                     ),
-                    source_ref = source_ref
+                    source_ref=source_ref,
                 ),
-                public_exc     = python_version >= 270,
-                source_ref     = source_ref
+                public_exc=python_version >= 270,
+                source_ref=source_ref,
             ),
-            final      = makeStatementConditional(
-                condition  = ExpressionComparisonIs(
-                    left       = ExpressionTempVariableRef(
-                        variable   = tmp_indicator_variable,
-                        source_ref = source_ref
+            final=makeStatementConditional(
+                condition=ExpressionComparisonIs(
+                    left=ExpressionTempVariableRef(
+                        variable=tmp_indicator_variable, source_ref=source_ref
                     ),
-                    right      = makeConstantRefNode(
-                        constant   = True,
-                        source_ref = source_ref
-                    ),
-                    source_ref = source_ref
+                    right=makeConstantRefNode(constant=True, source_ref=source_ref),
+                    source_ref=source_ref,
                 ),
-                yes_branch = StatementExpressionOnly(
-                    expression = exit_value_no_exception,
-                    source_ref = source_ref
+                yes_branch=StatementExpressionOnly(
+                    expression=exit_value_no_exception, source_ref=source_ref
                 ),
-                no_branch  = None,
-                source_ref = source_ref
+                no_branch=None,
+                source_ref=source_ref,
             ),
-            source_ref = source_ref
+            source_ref=source_ref,
         )
     ]
 
     return makeTryFinallyStatement(
-        provider   = provider,
-        tried      = statements,
-        final      = (
+        provider=provider,
+        tried=statements,
+        final=(
             StatementReleaseVariable(
-                variable   = tmp_source_variable,
-                source_ref = with_exit_source_ref
+                variable=tmp_source_variable, source_ref=with_exit_source_ref
             ),
             StatementReleaseVariable(
-                variable   = tmp_enter_variable,
-                source_ref = with_exit_source_ref
+                variable=tmp_enter_variable, source_ref=with_exit_source_ref
             ),
             StatementReleaseVariable(
-                variable   = tmp_exit_variable,
-                source_ref = with_exit_source_ref
+                variable=tmp_exit_variable, source_ref=with_exit_source_ref
             ),
             StatementReleaseVariable(
-                variable   = tmp_indicator_variable,
-                source_ref = with_exit_source_ref
+                variable=tmp_indicator_variable, source_ref=with_exit_source_ref
             ),
         ),
-        source_ref = source_ref
+        source_ref=source_ref,
     )
 
 
@@ -340,7 +303,6 @@ def buildWithNode(provider, node, source_ref):
         context_exprs = [node.context_expr]
         assign_targets = [node.optional_vars]
 
-
     # The body for the first context manager is the other things.
     body = buildStatementsNode(provider, node.body, source_ref)
 
@@ -358,13 +320,13 @@ def buildWithNode(provider, node, source_ref):
 
     for context_expr, assign_target in zip(context_exprs, assign_targets):
         body = _buildWithNode(
-            provider      = provider,
-            body          = body,
-            body_lineno   = body_lineno,
-            context_expr  = context_expr,
-            assign_target = assign_target,
-            sync          = True,
-            source_ref    = source_ref
+            provider=provider,
+            body=body,
+            body_lineno=body_lineno,
+            context_expr=context_expr,
+            assign_target=assign_target,
+            sync=True,
+            source_ref=source_ref,
         )
 
     return body
@@ -397,13 +359,13 @@ def buildAsyncWithNode(provider, node, source_ref):
 
     for context_expr, assign_target in zip(context_exprs, assign_targets):
         body = _buildWithNode(
-            provider      = provider,
-            body          = body,
-            body_lineno   = body_lineno,
-            context_expr  = context_expr,
-            assign_target = assign_target,
-            sync          = False,
-            source_ref    = source_ref
+            provider=provider,
+            body=body,
+            body_lineno=body_lineno,
+            context_expr=context_expr,
+            assign_target=assign_target,
+            sync=False,
+            source_ref=source_ref,
         )
 
     return body
